<div align="center">

<a alt="PyPackIT Test1: A New Python Project" href="https://AAriam.github.io/PyPackIT-Test1"><img alt="PyPackIT Test1: A New Python Project" src="https://raw.githubusercontent.com/AAriam/PyPackIT-Test1/main/docs/website/source/_media/logo/full_light.svg" title="Welcome to PyPackIT Test1! Click to visit our website and learn more." width="80%" /></a>

</div>

<div align="center">

<hr width="80%" />

<a alt="Intro" href="https://AAriam.github.io/PyPackIT-Test1/intro"><img alt="Intro" height="33px" src="https://img.shields.io/static/v1?message=Intro&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="Introduction and Background" /></a>&nbsp;&nbsp;<a alt="Manual" href="https://AAriam.github.io/PyPackIT-Test1/manual"><img alt="Manual" height="33px" src="https://img.shields.io/static/v1?message=Manual&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="User Manual" /></a>&nbsp;&nbsp;<a alt="News" href="https://AAriam.github.io/PyPackIT-Test1/news"><img alt="News" height="33px" src="https://img.shields.io/static/v1?message=News&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="Latest News and Releases" /></a>&nbsp;&nbsp;<a alt="Contribute" href="https://AAriam.github.io/PyPackIT-Test1/contribute"><img alt="Contribute" height="33px" src="https://img.shields.io/static/v1?message=Contribute&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="How to Contribute" /></a>&nbsp;&nbsp;<a alt="About" href="https://AAriam.github.io/PyPackIT-Test1/about"><img alt="About" height="33px" src="https://img.shields.io/static/v1?message=About&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="About the Project" /></a>&nbsp;&nbsp;<a alt="Help" href="https://AAriam.github.io/PyPackIT-Test1/help"><img alt="Help" height="33px" src="https://img.shields.io/static/v1?message=Help&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" title="Get Help and Support" /></a>

<hr width="100%" />

</div>

<img alt="First Keyword" height="23px" src="https://img.shields.io/static/v1?message=First%20Keyword&amp;label=Keywords&amp;style=flat-square&amp;color=%230B3C75&amp;labelColor=%23494949" />&nbsp;<img alt="Second Keyword" height="23px" src="https://img.shields.io/static/v1?message=Second%20Keyword&amp;label=&amp;style=flat-square&amp;color=%230B3C75" />&nbsp;<img alt="Third Keyword" height="23px" src="https://img.shields.io/static/v1?message=Third%20Keyword&amp;label=&amp;style=flat-square&amp;color=%230B3C75" />&nbsp;<img alt="Fourth Keyword" height="23px" src="https://img.shields.io/static/v1?message=Fourth%20Keyword&amp;label=&amp;style=flat-square&amp;color=%230B3C75" />&nbsp;<img alt="Fifth Keyword" height="23px" src="https://img.shields.io/static/v1?message=Fifth%20Keyword&amp;label=&amp;style=flat-square&amp;color=%230B3C75" />&nbsp;<img alt="Sixth Keyword" height="23px" src="https://img.shields.io/static/v1?message=Sixth%20Keyword&amp;label=&amp;style=flat-square&amp;color=%230B3C75" />

<p align="justify">
   Welcome to PyPackIT Test1 powered by <a href="https://pypackit.repodynamics.com/">PyPackIT</a>. Replace this text with a short abstract of PyPackIT Test1, describing its purpose and main feature. By default, this text is displayed on the repository's main README file, on the homepage of the project's website, on the project's PyPI and TestPyPI pages, and on the package's main docstring. Like all other entries in the repository's control center, this text can also contain dynamic references to other entries, using the <code>${‎{ json-path.to.value }}$</code> syntax. By default, the first occurrence of the name of the project in this text is styled as strong and linked to the project's website.
</p>

<a alt="10.5281/zenodo.14213694" href="https://doi.org/10.5281/zenodo.14213694"><img alt="10.5281/zenodo.14213694" height="23px" src="https://img.shields.io/static/v1?message=10.5281%2Fzenodo.14213694&amp;label=DOI&amp;style=flat-square&amp;color=%231682D4&amp;labelColor=%23494949&amp;logo=zenodo" /></a>&nbsp;&nbsp;<a alt="pip install PyPackIT-Test1" href="https://pypi.org/project/PyPackIT-Test1"><img alt="pip install PyPackIT-Test1" height="23px" src="https://img.shields.io/static/v1?message=pip%20install%20PyPackIT-Test1&amp;label=PyPI&amp;style=flat-square&amp;color=%233775A9&amp;labelColor=%23494949&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAC4AAAApCAYAAABKvBuPAAAACXBIWXMAAAewAAAHsAHUgoNiAAAIn0lEQVRYhcWZbUxb1xnHf7av7%2FX19cU2xoDBBEoJBAxJ6FJIaLYubZdKrdalW6Zu3bRN2qYp1bRqm9QvlaapUrcvU7Sqa%2BmHfli%2BbFNftGpV05ZV2Zq2NLRpIC%2BU0qQ0GBJejI2N8TV%2BvftAcCDYYCDt%2FpLl63v%2Bz3N%2Bvr7nnOf4ous6%2F8%2FX03999fUX3jjVtdE4g67rfNn64zMvPjUaiv1gLk3px1fnDNvKFNpqy6PbytSPf3H463uLyfGlgf%2Fh6X8cmZpP%2Fja4kL1lJKgZtUQ6r29XrUuvr3SGat32137yrTt%2BXCjfFwr%2BxJ%2F%2F3hVNZp6b0tLNoiQKjdVlzC%2Bk%2BNeHnxWMUSSRzmYvCd1E5y3Onh%2Fdv%2FfefD7hiwB%2B%2FOjfTk1FEy3TC1nVPxPLnT89MkOZKnGnz0tTlYP3hyc5758BYL%2BvBrMkMzaboHdUA%2BBr28u0Qn3cVPDf%2F%2BWFjw2i2Pza0ExBz0w0wduD47w9OM7dO7fx0x07GRif5%2FRVDUgV3ddNBZ%2BNLohvj0zSXGVHEU3EM1kGx8IrPN6yEhq8buIZA2cmNWSbzuBE%2FgtbLn56aHrg9XHNuP3lup3ff%2FQLA1%2FS0NUIAFZJwFdtx11iQVYUIkkTo6E4p0Zj62RYlJkw5cnnqzMov4p89NovY6Y9g0mTp7uu7aHumwZ%2B8mTfWyVW6Zbl57REmsErEbgS4cDues6MRTeV20QMe%2Bak0Z452RYQHnx2bCBw1LgV2BMnep%2F64IOB8cuXRzMdHa13i6J53Xy%2FfqAdj1PZUD9zxtsJiYeZk76J23wBRQjpm7riZ84M%2BG021dPZ2SqYTKai4372DR8P7d%2BOx2nlsWPvren1OiTCWR8R6RA24wgmzq5o3xS4u8xRk0plmJoKUF7uRhCKg2%2BscjC%2FkOL5fw%2FmbZfNRnZUKFSqMiFtAVlMYzfm924KXBBMqOrizx2LRYlEYsiyBYPBsGbcY8few%2BNUmJi9Pjh1XcfnUai2W0HX6RmeARbHwgM7SwszbBS6p%2BedI22tdbnPkihycczPu%2BdHUa0K9%2B2u48J4gOULz3ItQXsdEo1uG9vLZHo%2FCzE4UdxMsyHw48f%2F26Wq1qMVFa6v7NvXJsxHo5y%2FOM775%2FwMXQkzHIixvPbwOKwc7txOYE5jcHyGmWgCAJci0FCmUO2wcNo%2Fx4mLQYyCkXgquyHodcFPnux7y25XO7q62lSLxZI7f%2ByNft4dnmY8lH%2FhmAhrvNR3EYB9jZUcbHMgWQSyCPSNRmA0smHQ5cpmMRcEHxg4F6isdJapqpXl0AD9o7MYjQbaaxyIFjN9FwOr4vftqEK2Kvhnk%2FQPhXnkQC19%2FYVLgWKk6VWEUm1ohlpTQfD5aDxSV%2BspAwgEAiSTGUpKbKiqDQD%2FTAz%2FNW9zlR2XImIyC8iKjUAsQ%2F%2BExtIg24qSupNQ2sdCtgKX%2BTRe8U1ChjsXirrHVdviDBKZizEycmVV%2B9ISv6feRd%2FE1mFls5F2rw2rKBHJNFBpfneVpyjwkc%2BvYjaL1NSUU1HhhuPntwyXTz6PQku5mX1Vn9NV1s2Y4ee49Q%2FzeguCm0wm16h%2FGrfbSUtLQ1Edb2QVXZJihgdaHbS45znkPVp0XEFwgwGbvUQmHo8TjZpy9%2FZaMmAC1t9RuRSB1kob7Z4F2j3DNFleLBp4SQXBU%2BkMDocKQDab5eqVSTCA02nfcCcARgy0e1Vu9%2Bp0lJ%2Bh1f4fAIKGA8V81%2BLBjQZDrs1oNFJaWgJAIpmgvdaNzSIxdCVEoU3vknweheYKGyWyge4Df8rjWLtMuFEZZOIpm2UF%2BIkTvU%2FZbNbvlJc7PZJkzhsoiSL9owGGr0a4b3ctug7js1HO%2B0M5j9ch0VJZgioZefnsFIMTMZ6sKVx3FCNNryKcbiNpbqKk9s6k0NPzzhFFkY%2B43c7m5WXqTCC0Tio4PjCaOz7ceStGo4H6aoXT%2Fjl6Plm9KG1UWUxMp%2FaimXbiqruLKrsbgFAokhXq6yueFUWR0tLSTc0KS3qp7zP21Lu4MDu%2FJdgMMuF0E9FMA0mxlNrbnszrExSrjCxbcuWpqlpxOp1b6nwzCmebmU9vQ9ehRnoTlzDAmPS7gv7cPS6JIuVuEVhc4sGox%2BMLBlm2FIpdnaxwBZFXml5FNO0mmjlEnfQKDnGo6Ni8e0TVppBOpwxgYGIyTCgUI51ee%2FZYI90KJXUn06lOLicOkdHNqOZp6qRXrhtK7gCxct08a14iWZaQZQmAcEQjHo9hU0Ss0saurEsRSGUk%2FIn7kE0Bys19ubYg9deNyi6ofQJSU%2FDJw5sEv2Eb5rBbcVxbex7ev4MmT4DB8ZkV0%2BCN8nkUbi1T2dPgptkdoyZ%2BPF9H1w9L9i%2B%2BTx0rmFPTNMLhaGJTe87WhnJub9sGQM%2Bpiwz5Z%2Fno8iRwbQ73lNBSZed7996Wixm7dHr9xBPPwOybsHBpxelkMkkoFI1Ho9q5RCL1m9bW%2Bl4hnc5shj2ng3u3c3AvBGZjnLs0SVd7Mx735soCIAed1J0kkxn90qXxC4lEstvnq%2B%2BurHTlbEIwtPCIpmUft1oFj6JIRqNxc%2F8RuZ0K7Q3urUEDwfTubDTjndCy3pdbOu56tJBP2L17RzfQDXD27Kf%2FtMrmr9psYikbLSI2KV3XiWbq9HC6MaRlqweaOn54j2v9sJWDc9euxgcB%2BvuHu8xmy6szwXmrqooWSRSLgjALxfkgtyVLRHRfOpVqOdi699u9RQffCL6k9vamXsAFi19CkkzPWa3mZpsiCoJQeDyvV51eW86zs%2BnGwUTW1e3rPNy9%2FoydXxt6lDIw8MkR2SI%2BLpiz1U6Hyo3jYS66wLZtNavigsEQwenxVDo63N3S8d2C9%2B1GtOlnQOfPfXrMYjHfb7OJpbIsGmAluKZpBIPRoKbFB5qa6u65GbDLteWHV4vjwXjUYhFaTEZdla32FfPtTeJcpf8Bf0u4HEa2VhUAAAAASUVORK5CYII%3D" /></a>&nbsp;&nbsp;<a alt="PyPackIT-Test1" href="https://github.com/AAriam/PyPackIT-Test1/releases"><img alt="PyPackIT-Test1" height="23px" src="https://img.shields.io/static/v1?message=PyPackIT-Test1&amp;label=GitHub&amp;style=flat-square&amp;color=%23181717&amp;labelColor=%23494949&amp;logo=github" /></a>&nbsp;&nbsp;<a alt="try online" href="https://mybinder.org/v2/gh/AAriam/PyPackIT-Test1/main"><img alt="try online" height="23px" src="https://img.shields.io/static/v1?message=try%20online&amp;label=Binder&amp;style=flat-square&amp;color=%23579ACA&amp;labelColor=%23494949&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAFkAAABZCAMAAABi1XidAAAB8lBMVEX%2F%2F%2F9XmsrmZYH1olJXmsr1olJXmsrmZYH1olJXmsr1olJXmsrmZYH1olL1olJXmsr1olJXmsrmZYH1olL1olJXmsrmZYH1olJXmsr1olL1olJXmsrmZYH1olL1olJXmsrmZYH1olL1olL0nFf1olJXmsrmZYH1olJXmsq8dZb1olJXmsrmZYH1olJXmspXmspXmsr1olL1olJXmsrmZYH1olJXmsr1olL1olJXmsrmZYH1olL1olLeaIVXmsrmZYH1olL1olL1olJXmsrmZYH1olLna31Xmsr1olJXmsr1olJXmsrmZYH1olLqoVr1olJXmsr1olJXmsrmZYH1olL1olKkfaPobXvviGabgadXmsqThKuofKHmZ4Dobnr1olJXmsr1olJXmspXmsr1olJXmsrfZ4TuhWn1olL1olJXmsqBi7X1olJXmspZmslbmMhbmsdemsVfl8ZgmsNim8Jpk8F0m7R4m7F5nLB6jbh7jbiDirOEibOGnKaMhq%2BPnaCVg6qWg6qegKaff6WhnpKofKGtnomxeZy3noG6dZi%2Bn3vCcpPDcpPGn3bLb4%2FMb47UbIrVa4rYoGjdaIbeaIXhoWHmZYHobXvpcHjqdHXreHLroVrsfG%2FuhGnuh2bwj2Hxk17yl1vzmljzm1j0nlX1olL3AJXWAAAAbXRSTlMAEBAQHx8gICAuLjAwMDw9PUBAQEpQUFBXV1hgYGBkcHBwcXl8gICAgoiIkJCQlJicnJ2goKCmqK%2BwsLC4usDAwMjP0NDQ1NbW3Nzg4ODi5%2B3v8PDw8%2FT09PX29vb39%2Ff5%2Bfr7%2B%2Fz8%2FPz9%2Fv7%2BzczCxgAABC5JREFUeAHN1ul3k0UUBvCb1CTVpmpaitAGSLSpSuKCLWpbTKNJFGlcSMAFF63iUmRccNG6gLbuxkXU66JAUef%2F9LSpmXnyLr3T5AO%2Frzl5zj137p136BISy44fKJXuGN%2Fd19PUfYeO67Znqtf2KH33Id1psXoFdW30sPZ1sMvs2D060AHqws4FHeJojLZqnw53cmfvg%2BXR8mC0OEjuxrXEkX5ydeVJLVIlV0e10PXk5k7dYeHu7Cj1j%2B49uKg7uLU61tGLw1lq27ugQYlclHC4bgv7VQ%2BTAyj5Zc%2FUjsPvs1sd5cWryWObtvWT2EPa4rtnWW3JkpjggEpbOsPr7F7EyNewtpBIslA7p43HCsnwooXTEc3UmPmCNn5lrqTJxy6nRmcavGZVt%2F3Da2pD5NHvsOHJCrdc1G2r3DITpU7yic7w%2F7Rxnjc0kt5GC4djiv2Sz3Fb2iEZg41%2FddsFDoyuYrIkmFehz0HR2thPgQqMyQYb2OtB0WxsZ3BeG3%2BwpRb1vzl2UYBog8FfGhttFKjtAclnZYrRo9ryG9uG%2FFZQU4AEg8ZE9LjGMzTmqKXPLnlWVnIlQQTvxJf8ip7VgjZjyVPrjw1te5otM7RmP7xm%2BsK2Gv9I8Gi%2B%2BBRbEkR9EBw8zRUcKxwp73xkaLiqQb%2BkGduJTNHG72zcW9LoJgqQxpP3%2FTj%2F%2Fc3yB0tqzaml05%2F%2BorHLksVO%2B95kX7%2F7qgJvnjlrfr2Ggsyx0eoy9uPzN5SPd86aXggOsEKW2Prz7du3VID3%2Ftzs%2FsSRs2w7ovVHKtjrX2pd7ZMlTxAYfBAL9jiDwfLkq55Tm7ifhMlTGPyCAs7RFRhn47JnlcB9RM5T97ASuZXIcVNuUDIndpDbdsfrqsOppeXl5Y%2BXVKdjFCTh%2BzGaVuj0d9zy05PPK3QzBamxdwtTCrzyg%2F2Rvf2EstUjordGwa%2Fkx9mSJLr8mLLtCW8HHGJc2R5hS219IiF6PnTusOqcMl57gm0Z8kanKMAQg0qSyuZfn7zItsbGyO9QlnxY0eCuD1XL2ys%2FMsrQhltE7Ug0uFOzufJFE2PxBo%2FYAx8XPPdDwWN0MrDRYIZF0mSMKCNHgaIVFoBbNoLJ7tEQDKxGF0kcLQimojCZopv0OkNOyWCCg9XMVAi7ARJzQdM2QUh0gmBozjc3Skg6dSBRqDGYSUOu66Zg%2BI2fNZs%2FM3%2Ff%2FGrl%2FXnyF1Gw3VKCez0PN5IUfFLqvgUN4C0qNqYs5YhPL%2BaVZYDE4IpUk57oSFnJm4FyCqqOE0jhY2SMyLFoo56zyo6becOS5UVDdj7Vih0zp%2BtcMhwRpBeLyqtIjlJKAIZSbI8SGSF3k0pA3mR5tHuwPFoa7N7reoq2bqCsAk1HqCu5uvI1n6JuRXI%2BS1Mco54YmYTwcn6Aeic%2BkssXi8XpXC4V3t7%2FADuTNKaQJdScAAAAAElFTkSuQmCC" title="Launch Jupyter notebook in Binder." /></a>

<h2>

Highlights

</h2>

<img align="left" alt="First Key Feature" height="30px" src="https://img.shields.io/static/v1?message=First%20Key%20Feature&amp;label=&amp;style=for-the-badge&amp;color=%230F3460" /><p align="justify">
   Description of the first key feature of PyPackIT Test1. By default, these highlights are displayed on the repository's main README file, on the homepage of the project's website, and on the project's PyPI and TestPyPI pages.
</p>

<img align="left" alt="Second Key Feature" height="30px" src="https://img.shields.io/static/v1?message=Second%20Key%20Feature&amp;label=&amp;style=for-the-badge&amp;color=%23333034" /><p align="justify">
   Description of the second key feature of PyPackIT Test1. For aesthetic reasons, it is recommended to keep the descriptions of all items in this list approximately the same length.
</p>

<img align="left" alt="Third Key Feature" height="30px" src="https://img.shields.io/static/v1?message=Third%20Key%20Feature&amp;label=&amp;style=for-the-badge&amp;color=%23562B08" /><p align="justify">
   Description of the third key feature of PyPackIT Test1. You can add as many keynotes as you want. However, in order to keep the READMEs clean and tidy, it is recommended to keep the number of keynotes between 3 and 7.
</p>

<h2>

Latest Release

</h2>

<img alt="0.0.9" height="23px" src="https://img.shields.io/static/v1?message=0.0.9&amp;label=PyPackIT-Test1&amp;style=flat-square&amp;color=%23562B08&amp;labelColor=%230F3460&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyBpZD0iTGF5ZXJfMiIgZGF0YS1uYW1lPSJMYXllciAyIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA4OSA4OSI%2BCiAgPGRlZnM%2BCiAgICA8c3R5bGU%2BCiAgICAgIC5jbHMtMSB7CiAgICAgICAgZmlsbDogIzAwOTI0NTsKICAgICAgfQoKICAgICAgLmNscy0xLCAuY2xzLTIgewogICAgICAgIHN0cm9rZTogI2ZmZjsKICAgICAgICBzdHJva2UtbWl0ZXJsaW1pdDogMTA7CiAgICAgIH0KCiAgICAgIC5jbHMtMiB7CiAgICAgICAgZmlsbDogI2MxMjcyZDsKICAgICAgfQogICAgPC9zdHlsZT4KICA8L2RlZnM% %2BCjwvc3ZnPgo%3D" />&nbsp;&nbsp;<img alt="major" height="23px" src="https://img.shields.io/static/v1?message=major&amp;label=%F0%9F%92%A5%E2%80%82Release%20Type&amp;style=flat-square&amp;color=%23AF1F10&amp;labelColor=%23494949" />&nbsp;&nbsp;<img alt="2024-11-25" height="23px" src="https://img.shields.io/static/v1?message=2024-11-25&amp;label=%F0%9F%97%93%E2%80%82Release%20Date&amp;style=flat-square&amp;color=%230B3C75&amp;labelColor=%23494949" />&nbsp;&nbsp;<a alt="PyPackIT-Test1 == 0.0.9" href="https://pypi.org/project/PyPackIT-Test1"><img alt="PyPackIT-Test1 == 0.0.9" height="23px" src="https://img.shields.io/static/v1?message=PyPackIT-Test1%20%3D%3D%200.0.9&amp;label=pip%20install&amp;style=flat-square&amp;color=%233775A9&amp;labelColor=%23494949&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAC4AAAApCAYAAABKvBuPAAAACXBIWXMAAAewAAAHsAHUgoNiAAAIn0lEQVRYhcWZbUxb1xnHf7av7%2FX19cU2xoDBBEoJBAxJ6FJIaLYubZdKrdalW6Zu3bRN2qYp1bRqm9QvlaapUrcvU7Sqa%2BmHfli%2BbFNftGpV05ZV2Zq2NLRpIC%2BU0qQ0GBJejI2N8TV%2BvftAcCDYYCDt%2FpLl63v%2Bz3N%2Bvr7nnOf4ous6%2F8%2FX03999fUX3jjVtdE4g67rfNn64zMvPjUaiv1gLk3px1fnDNvKFNpqy6PbytSPf3H463uLyfGlgf%2Fh6X8cmZpP%2Fja4kL1lJKgZtUQ6r29XrUuvr3SGat32137yrTt%2BXCjfFwr%2BxJ%2F%2F3hVNZp6b0tLNoiQKjdVlzC%2Bk%2BNeHnxWMUSSRzmYvCd1E5y3Onh%2Fdv%2FfefD7hiwB%2B%2FOjfTk1FEy3TC1nVPxPLnT89MkOZKnGnz0tTlYP3hyc5758BYL%2BvBrMkMzaboHdUA%2BBr28u0Qn3cVPDf%2F%2BWFjw2i2Pza0ExBz0w0wduD47w9OM7dO7fx0x07GRif5%2FRVDUgV3ddNBZ%2BNLohvj0zSXGVHEU3EM1kGx8IrPN6yEhq8buIZA2cmNWSbzuBE%2FgtbLn56aHrg9XHNuP3lup3ff%2FQLA1%2FS0NUIAFZJwFdtx11iQVYUIkkTo6E4p0Zj62RYlJkw5cnnqzMov4p89NovY6Y9g0mTp7uu7aHumwZ%2B8mTfWyVW6Zbl57REmsErEbgS4cDues6MRTeV20QMe%2Bak0Z452RYQHnx2bCBw1LgV2BMnep%2F64IOB8cuXRzMdHa13i6J53Xy%2FfqAdj1PZUD9zxtsJiYeZk76J23wBRQjpm7riZ84M%2BG021dPZ2SqYTKai4372DR8P7d%2BOx2nlsWPvren1OiTCWR8R6RA24wgmzq5o3xS4u8xRk0plmJoKUF7uRhCKg2%2BscjC%2FkOL5fw%2FmbZfNRnZUKFSqMiFtAVlMYzfm924KXBBMqOrizx2LRYlEYsiyBYPBsGbcY8few%2BNUmJi9Pjh1XcfnUai2W0HX6RmeARbHwgM7SwszbBS6p%2BedI22tdbnPkihycczPu%2BdHUa0K9%2B2u48J4gOULz3ItQXsdEo1uG9vLZHo%2FCzE4UdxMsyHw48f%2F26Wq1qMVFa6v7NvXJsxHo5y%2FOM775%2FwMXQkzHIixvPbwOKwc7txOYE5jcHyGmWgCAJci0FCmUO2wcNo%2Fx4mLQYyCkXgquyHodcFPnux7y25XO7q62lSLxZI7f%2ByNft4dnmY8lH%2FhmAhrvNR3EYB9jZUcbHMgWQSyCPSNRmA0smHQ5cpmMRcEHxg4F6isdJapqpXl0AD9o7MYjQbaaxyIFjN9FwOr4vftqEK2Kvhnk%2FQPhXnkQC19%2FYVLgWKk6VWEUm1ohlpTQfD5aDxSV%2BspAwgEAiSTGUpKbKiqDQD%2FTAz%2FNW9zlR2XImIyC8iKjUAsQ%2F%2BExtIg24qSupNQ2sdCtgKX%2BTRe8U1ChjsXirrHVdviDBKZizEycmVV%2B9ISv6feRd%2FE1mFls5F2rw2rKBHJNFBpfneVpyjwkc%2BvYjaL1NSUU1HhhuPntwyXTz6PQku5mX1Vn9NV1s2Y4ee49Q%2FzeguCm0wm16h%2FGrfbSUtLQ1Edb2QVXZJihgdaHbS45znkPVp0XEFwgwGbvUQmHo8TjZpy9%2FZaMmAC1t9RuRSB1kob7Z4F2j3DNFleLBp4SQXBU%2BkMDocKQDab5eqVSTCA02nfcCcARgy0e1Vu9%2Bp0lJ%2Bh1f4fAIKGA8V81%2BLBjQZDrs1oNFJaWgJAIpmgvdaNzSIxdCVEoU3vknweheYKGyWyge4Df8rjWLtMuFEZZOIpm2UF%2BIkTvU%2FZbNbvlJc7PZJkzhsoiSL9owGGr0a4b3ctug7js1HO%2B0M5j9ch0VJZgioZefnsFIMTMZ6sKVx3FCNNryKcbiNpbqKk9s6k0NPzzhFFkY%2B43c7m5WXqTCC0Tio4PjCaOz7ceStGo4H6aoXT%2Fjl6Plm9KG1UWUxMp%2FaimXbiqruLKrsbgFAokhXq6yueFUWR0tLSTc0KS3qp7zP21Lu4MDu%2FJdgMMuF0E9FMA0mxlNrbnszrExSrjCxbcuWpqlpxOp1b6nwzCmebmU9vQ9ehRnoTlzDAmPS7gv7cPS6JIuVuEVhc4sGox%2BMLBlm2FIpdnaxwBZFXml5FNO0mmjlEnfQKDnGo6Ni8e0TVppBOpwxgYGIyTCgUI51ee%2FZYI90KJXUn06lOLicOkdHNqOZp6qRXrhtK7gCxct08a14iWZaQZQmAcEQjHo9hU0Ss0saurEsRSGUk%2FIn7kE0Bys19ubYg9deNyi6ofQJSU%2FDJw5sEv2Eb5rBbcVxbex7ev4MmT4DB8ZkV0%2BCN8nkUbi1T2dPgptkdoyZ%2BPF9H1w9L9i%2B%2BTx0rmFPTNMLhaGJTe87WhnJub9sGQM%2Bpiwz5Z%2Fno8iRwbQ73lNBSZed7996Wixm7dHr9xBPPwOybsHBpxelkMkkoFI1Ho9q5RCL1m9bW%2Bl4hnc5shj2ng3u3c3AvBGZjnLs0SVd7Mx735soCIAed1J0kkxn90qXxC4lEstvnq%2B%2BurHTlbEIwtPCIpmUft1oFj6JIRqNxc%2F8RuZ0K7Q3urUEDwfTubDTjndCy3pdbOu56tJBP2L17RzfQDXD27Kf%2FtMrmr9psYikbLSI2KV3XiWbq9HC6MaRlqweaOn54j2v9sJWDc9euxgcB%2BvuHu8xmy6szwXmrqooWSRSLgjALxfkgtyVLRHRfOpVqOdi699u9RQffCL6k9vamXsAFi19CkkzPWa3mZpsiCoJQeDyvV51eW86zs%2BnGwUTW1e3rPNy9%2FoydXxt6lDIw8MkR2SI%2BLpiz1U6Hyo3jYS66wLZtNavigsEQwenxVDo63N3S8d2C9%2B1GtOlnQOfPfXrMYjHfb7OJpbIsGmAluKZpBIPRoKbFB5qa6u65GbDLteWHV4vjwXjUYhFaTEZdla32FfPtTeJcpf8Bf0u4HEa2VhUAAAAASUVORK5CYII%3D" /></a>&nbsp;&nbsp;<a alt="ver/0.0.9" href="https://github.com/AAriam/PyPackIT-Test1/releases"><img alt="ver/0.0.9" height="23px" src="https://img.shields.io/static/v1?message=ver%2F0.0.9&amp;label=git%20checkout&amp;style=flat-square&amp;color=%23181717&amp;labelColor=%23494949&amp;logo=github" /></a>&nbsp;&nbsp;<a alt="try online" href="https://mybinder.org/v2/gh/AAriam/PyPackIT-Test1/ver/0.0.9"><img alt="try online" height="23px" src="https://img.shields.io/static/v1?message=try%20online&amp;label=Binder&amp;style=flat-square&amp;color=%23579ACA&amp;labelColor=%23494949&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAFkAAABZCAMAAABi1XidAAAB8lBMVEX%2F%2F%2F9XmsrmZYH1olJXmsr1olJXmsrmZYH1olJXmsr1olJXmsrmZYH1olL1olJXmsr1olJXmsrmZYH1olL1olJXmsrmZYH1olJXmsr1olL1olJXmsrmZYH1olL1olJXmsrmZYH1olL1olL0nFf1olJXmsrmZYH1olJXmsq8dZb1olJXmsrmZYH1olJXmspXmspXmsr1olL1olJXmsrmZYH1olJXmsr1olL1olJXmsrmZYH1olL1olLeaIVXmsrmZYH1olL1olL1olJXmsrmZYH1olLna31Xmsr1olJXmsr1olJXmsrmZYH1olLqoVr1olJXmsr1olJXmsrmZYH1olL1olKkfaPobXvviGabgadXmsqThKuofKHmZ4Dobnr1olJXmsr1olJXmspXmsr1olJXmsrfZ4TuhWn1olL1olJXmsqBi7X1olJXmspZmslbmMhbmsdemsVfl8ZgmsNim8Jpk8F0m7R4m7F5nLB6jbh7jbiDirOEibOGnKaMhq%2BPnaCVg6qWg6qegKaff6WhnpKofKGtnomxeZy3noG6dZi%2Bn3vCcpPDcpPGn3bLb4%2FMb47UbIrVa4rYoGjdaIbeaIXhoWHmZYHobXvpcHjqdHXreHLroVrsfG%2FuhGnuh2bwj2Hxk17yl1vzmljzm1j0nlX1olL3AJXWAAAAbXRSTlMAEBAQHx8gICAuLjAwMDw9PUBAQEpQUFBXV1hgYGBkcHBwcXl8gICAgoiIkJCQlJicnJ2goKCmqK%2BwsLC4usDAwMjP0NDQ1NbW3Nzg4ODi5%2B3v8PDw8%2FT09PX29vb39%2Ff5%2Bfr7%2B%2Fz8%2FPz9%2Fv7%2BzczCxgAABC5JREFUeAHN1ul3k0UUBvCb1CTVpmpaitAGSLSpSuKCLWpbTKNJFGlcSMAFF63iUmRccNG6gLbuxkXU66JAUef%2F9LSpmXnyLr3T5AO%2Frzl5zj137p136BISy44fKJXuGN%2Fd19PUfYeO67Znqtf2KH33Id1psXoFdW30sPZ1sMvs2D060AHqws4FHeJojLZqnw53cmfvg%2BXR8mC0OEjuxrXEkX5ydeVJLVIlV0e10PXk5k7dYeHu7Cj1j%2B49uKg7uLU61tGLw1lq27ugQYlclHC4bgv7VQ%2BTAyj5Zc%2FUjsPvs1sd5cWryWObtvWT2EPa4rtnWW3JkpjggEpbOsPr7F7EyNewtpBIslA7p43HCsnwooXTEc3UmPmCNn5lrqTJxy6nRmcavGZVt%2F3Da2pD5NHvsOHJCrdc1G2r3DITpU7yic7w%2F7Rxnjc0kt5GC4djiv2Sz3Fb2iEZg41%2FddsFDoyuYrIkmFehz0HR2thPgQqMyQYb2OtB0WxsZ3BeG3%2BwpRb1vzl2UYBog8FfGhttFKjtAclnZYrRo9ryG9uG%2FFZQU4AEg8ZE9LjGMzTmqKXPLnlWVnIlQQTvxJf8ip7VgjZjyVPrjw1te5otM7RmP7xm%2BsK2Gv9I8Gi%2B%2BBRbEkR9EBw8zRUcKxwp73xkaLiqQb%2BkGduJTNHG72zcW9LoJgqQxpP3%2FTj%2F%2Fc3yB0tqzaml05%2F%2BorHLksVO%2B95kX7%2F7qgJvnjlrfr2Ggsyx0eoy9uPzN5SPd86aXggOsEKW2Prz7du3VID3%2Ftzs%2FsSRs2w7ovVHKtjrX2pd7ZMlTxAYfBAL9jiDwfLkq55Tm7ifhMlTGPyCAs7RFRhn47JnlcB9RM5T97ASuZXIcVNuUDIndpDbdsfrqsOppeXl5Y%2BXVKdjFCTh%2BzGaVuj0d9zy05PPK3QzBamxdwtTCrzyg%2F2Rvf2EstUjordGwa%2Fkx9mSJLr8mLLtCW8HHGJc2R5hS219IiF6PnTusOqcMl57gm0Z8kanKMAQg0qSyuZfn7zItsbGyO9QlnxY0eCuD1XL2ys%2FMsrQhltE7Ug0uFOzufJFE2PxBo%2FYAx8XPPdDwWN0MrDRYIZF0mSMKCNHgaIVFoBbNoLJ7tEQDKxGF0kcLQimojCZopv0OkNOyWCCg9XMVAi7ARJzQdM2QUh0gmBozjc3Skg6dSBRqDGYSUOu66Zg%2BI2fNZs%2FM3%2Ff%2FGrl%2FXnyF1Gw3VKCez0PN5IUfFLqvgUN4C0qNqYs5YhPL%2BaVZYDE4IpUk57oSFnJm4FyCqqOE0jhY2SMyLFoo56zyo6becOS5UVDdj7Vih0zp%2BtcMhwRpBeLyqtIjlJKAIZSbI8SGSF3k0pA3mR5tHuwPFoa7N7reoq2bqCsAk1HqCu5uvI1n6JuRXI%2BS1Mco54YmYTwcn6Aeic%2BkssXi8XpXC4V3t7%2FADuTNKaQJdScAAAAAElFTkSuQmCC" title="Launch Jupyter notebook in Binder." /></a>

**Project Initialization**

This is an initial emtpy release.

<h3>

Latest Developmental Release

</h3>

<a alt="10.5072/zenodo.136379" href="https://sandbox.zenodo.org/uploads/136379"><img alt="10.5072/zenodo.136379" height="23px" src="https://img.shields.io/static/v1?message=10.5072%2Fzenodo.136379&amp;label=DOI&amp;style=flat-square&amp;color=%231682D4&amp;labelColor=%23494949&amp;logoColor=%231682D4&amp;logo=zenodo" /></a>

<h3>

Requirements

</h3>

<img alt="⚙️ Operating System" height="23px" src="https://img.shields.io/static/v1?message=%E2%9A%99%EF%B8%8F%E2%80%82Operating%20System&amp;label=&amp;style=flat-square&amp;color=%23494949" />&nbsp;<img alt="any" height="23px" src="https://img.shields.io/static/v1?message=any&amp;label=Linux&amp;style=flat-square&amp;color=%2300802B&amp;labelColor=%23494949&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAABwAAAAjCAYAAACHIWrsAAAACXBIWXMAAA9gAAAPYAF6eEWNAAAEoUlEQVRIia2XX0xbVRzHf%2Be25U%2FY6C0iazZJO4OIM2Qnylw3HKvJEJdgLMISMh64gcYx4r8HmHVPzRbmnrQDH3xyvIljM41ZMIuYFDQ2TDdvxKmxS1ZI7NoJ5YLQ25a2Px%2FoLRdse28XfslJ7v2d3z2f8zvnd7%2F3XIKIUIgRQlgAoDIXj4iC6gEQUVUDABYARgEAszSX6nEKAPI5YAVB1cJsCjCpmZXGYlSuvFVlnE0pQC2QUkrB4XAsSY729vbI8PDwHKXy%2BgGz4kgql9QTDocFRESHwxGmlCIiYjQaFaPRqAibS%2BrZqSUFg8GgHxwcjLa0tCSPvnQAAoFAyGg0lhQXF5dsyzKvqQZ6vd6oMXWN3L91ovKTrnF4OHmQOW%2FfFxNFMc7zvGqgVmWckPztNfGdN0SDNMd68%2FKT1ZXL8Ne4IWwykoq5oDoBUZshe3N6dffX36cyjmke4eLVJCRSSQKacslt3ikgLap6XbsqasSLV5MwMp4C%2FS6AlmOmZeMrv6SaT54S03EmQog170gqKpQDAPT5fP545FFkeswW%2FurTl5duT489wrR5vd552KxUPwCwj6U0sKGfAsuyqGQsy8oVZ%2FRxXws3AOg7OjpEhTjo6%2Btbkt12E0K4gpYUAFzSjGdnZ4NKGYbDYQEAkOM4eaZU1ZLChnaiy%2BVCSVXUmN1ujzidTqSUSkBeLZCnlCLHceh2uxWz256lx%2BORZ8nlBUpV6XQ60Ww2q85OniXHcWiz2TJVKx8%2FW9FkNruzs3MpS39e6%2B3tXfB4PNDQ0BBLu0yEkIzYbgGmzyvHpfvu7u5IoUCLxVINANDc3Lwuc1uzAkF2OKqpqYnX1dXtKxQIsCH0KysrSZZlJVfmYvv%2BvQ%2FpzQ6FQmsFbyAiDgwMiACAVqsV3W63VLHOrEWzfy%2F5cOiMRhg6oxHsdnukUNifd75Y6mllIrBZoeh0OrdU6pZ3b%2ByCZjE2pcPYlA6%2FvaL9x2q1ovSlV7J4PL425y5bXP1Ot2YyEuxpZSJ3R7VB%2Fw1t8OybzLyMA2xrI8PfHdUGJZjUelqZCMuy6Pf7F5WAPp%2FPv%2F15qf07qYs8U036ERGYxnoyeeOS5uDz%2B8me7Zt%2FqU8Th4QAlNKKeDyeV081Il%2Baq69IB6Unj5B3AQCYoiKoyxVo2A36z85pwoIgwMzMzHI%2B4B%2F8NyRf%2F3unmCcIIVamrITczxfYdpypuHzuaMxisZTniyuN%2FZj3y%2FNUFakcOM18zFSUK59r%2Bl%2F9CQOBQDRXv8fjWdhbPpdXJGLrEL39Oy5rDz1HFIHFOii58PbTyBh7xLa2toXa2tpUIpHQTkxMaEdGRvb4%2Ff7K2JQu67PrCYhcuZZaH7menAguQj9prCc%2Ff9SvqaozkV36MjDkgt57gKEXuMT%2FCiuTQRbgfAjDtg%2BSd%2B49wLcQ0Q8AoP3h11QDIcQGG7JmPnyAHBnsYvQth5nyIh1kKs%2F1ZWoBAC7Dxl8Uj4hCWpRZALBN89jVREmlHHbsbOLWwwU8vWUWmP17aAWA0ROHSLCJEnzxWfJ5tjhZPAsAfBMleH1IEzzfzfwNMjmTNyK9%2FTthsoxz%2FhX%2FB8J3ZR%2FKxquaAAAAAElFTkSuQmCC" />&nbsp;<img alt="any" height="23px" src="https://img.shields.io/static/v1?message=any&amp;label=macOS&amp;style=flat-square&amp;color=%2300802B&amp;labelColor=%23494949&amp;logoColor=%23000000&amp;logo=apple" />&nbsp;<img alt="any" height="23px" src="https://img.shields.io/static/v1?message=any&amp;label=Windows&amp;style=flat-square&amp;color=%2300802B&amp;labelColor=%23494949&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyMyAyMyI%2BPHBhdGggZmlsbD0iI2YzZjNmMyIgZD0iTTAgMGgyM3YyM0gweiIvPjxwYXRoIGZpbGw9IiNmMzUzMjUiIGQ9Ik0xIDFoMTB2MTBIMXoiLz48cGF0aCBmaWxsPSIjODFiYzA2IiBkPSJNMTIgMWgxMHYxMEgxMnoiLz48cGF0aCBmaWxsPSIjMDVhNmYwIiBkPSJNMSAxMmgxMHYxMEgxeiIvPjxwYXRoIGZpbGw9IiNmZmJhMDgiIGQ9Ik0xMiAxMmgxMHYxMEgxMnoiLz48L3N2Zz4%3D" />

<img alt="Python" height="23px" src="https://img.shields.io/static/v1?message=Python&amp;label=&amp;style=flat-square&amp;color=%23494949&amp;labelColor=%23494949&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB2aWV3Qm94PSIwIDAgMTExLjE2MTYgMTEyLjM4OCIgdmVyc2lvbj0iMS4wIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOmNjPSJodHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9ucyMiIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4xLyIgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayI%2BCjxtZXRhZGF0YT4KPHJkZjpSREY%2BCjxjYzpXb3JrIHJkZjphYm91dD0iIj4KPGRjOmZvcm1hdD5pbWFnZS9zdmcreG1sPC9kYzpmb3JtYXQ%2BCjxkYzp0eXBlIHJkZjpyZXNvdXJjZT0iaHR0cDovL3B1cmwub3JnL2RjL2RjbWl0eXBlL1N0aWxsSW1hZ2UiLz4KPC9jYzpXb3JrPgo8L3JkZjpSREY%2BCjwvbWV0YWRhdGE%2BCjxkZWZzPgo8bGluZWFyR3JhZGllbnQgaWQ9ImIiIHgxPSIxNTAuOTYiIHgyPSIxMTIuMDMiIHkxPSIxOTIuMzUiIHkyPSIxMzcuMjciIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoLjU2MjU0IDAgMCAuNTY3OTcgLTE0Ljk5MSAtMTEuNzAyKSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiPgo8c3RvcCBzdG9wLWNvbG9yPSIjZmZkNDNiIiBvZmZzZXQ9IjAiLz4KPHN0b3Agc3RvcC1jb2xvcj0iI2ZmZTg3MyIgb2Zmc2V0PSIxIi8%2BCjwvbGluZWFyR3JhZGllbnQ%2BCjxsaW5lYXJHcmFkaWVudCBpZD0iYSIgeDE9IjI2LjY0OSIgeDI9IjEzNS42NyIgeTE9IjIwLjYwNCIgeTI9IjExNC40IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KC41NjI1NCAwIDAgLjU2Nzk3IC0xNC45OTEgLTExLjcwMikiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIj4KPHN0b3Agc3RvcC1jb2xvcj0iIzVhOWZkNCIgb2Zmc2V0PSIwIi8%2BCjxzdG9wIHN0b3AtY29sb3I9IiMzMDY5OTgiIG9mZnNldD0iMSIvPgo8L2xpbmVhckdyYWRpZW50Pgo8L2RlZnM% " />&nbsp;<img alt="3.10 | 3.11 | 3.12 | 3.13" height="23px" src="https://img.shields.io/static/v1?message=3.10%20%7C%203.11%20%7C%203.12%20%7C%203.13&amp;label=Versions&amp;style=flat-square&amp;color=%230B3C75&amp;labelColor=%23494949" />&nbsp;<img alt="any" height="23px" src="https://img.shields.io/static/v1?message=any&amp;label=Implementation&amp;style=flat-square&amp;color=%2300802B&amp;labelColor=%23494949" />

<img alt="📦 Dependencies" height="23px" src="https://img.shields.io/static/v1?message=%F0%9F%93%A6%E2%80%82Dependencies&amp;label=&amp;style=flat-square&amp;color=%23494949" />&nbsp;<img alt="any" height="23px" src="https://img.shields.io/static/v1?message=any&amp;label=PkgData&amp;style=flat-square&amp;color=%2300802B&amp;labelColor=%23494949" />

<h3>

Interfaces

</h3>

<img alt="API" height="23px" src="https://img.shields.io/static/v1?message=API&amp;label=&amp;style=flat-square&amp;color=%23494949&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB2aWV3Qm94PSIwIDAgMTExLjE2MTYgMTEyLjM4OCIgdmVyc2lvbj0iMS4wIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOmNjPSJodHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9ucyMiIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4xLyIgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayI%2BCjxtZXRhZGF0YT4KPHJkZjpSREY%2BCjxjYzpXb3JrIHJkZjphYm91dD0iIj4KPGRjOmZvcm1hdD5pbWFnZS9zdmcreG1sPC9kYzpmb3JtYXQ%2BCjxkYzp0eXBlIHJkZjpyZXNvdXJjZT0iaHR0cDovL3B1cmwub3JnL2RjL2RjbWl0eXBlL1N0aWxsSW1hZ2UiLz4KPC9jYzpXb3JrPgo8L3JkZjpSREY%2BCjwvbWV0YWRhdGE%2BCjxkZWZzPgo8bGluZWFyR3JhZGllbnQgaWQ9ImIiIHgxPSIxNTAuOTYiIHgyPSIxMTIuMDMiIHkxPSIxOTIuMzUiIHkyPSIxMzcuMjciIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoLjU2MjU0IDAgMCAuNTY3OTcgLTE0Ljk5MSAtMTEuNzAyKSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiPgo8c3RvcCBzdG9wLWNvbG9yPSIjZmZkNDNiIiBvZmZzZXQ9IjAiLz4KPHN0b3Agc3RvcC1jb2xvcj0iI2ZmZTg3MyIgb2Zmc2V0PSIxIi8%2BCjwvbGluZWFyR3JhZGllbnQ%2BCjxsaW5lYXJHcmFkaWVudCBpZD0iYSIgeDE9IjI2LjY0OSIgeDI9IjEzNS42NyIgeTE9IjIwLjYwNCIgeTI9IjExNC40IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KC41NjI1NCAwIDAgLjU2Nzk3IC0xNC45OTEgLTExLjcwMikiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIj4KPHN0b3Agc3RvcC1jb2xvcj0iIzVhOWZkNCIgb2Zmc2V0PSIwIi8%2BCjxzdG9wIHN0b3AtY29sb3I9IiMzMDY5OTgiIG9mZnNldD0iMSIvPgo8L2xpbmVhckdyYWRpZW50Pgo8L2RlZnM% " />&nbsp;<img alt="pypackit_test1" height="23px" src="https://img.shields.io/static/v1?message=pypackit_test1&amp;label=import&amp;style=flat-square&amp;color=%233776AB&amp;labelColor=%23494949" title="Main Python API entry of the package." />

<img alt="CLI" height="23px" src="https://img.shields.io/static/v1?message=CLI&amp;label=&amp;style=flat-square&amp;color=%23494949&amp;logoColor=%234EAA25&amp;logo=gnubash" />&nbsp;<img alt="PyPackIT-Test1" height="23px" src="https://img.shields.io/static/v1?message=PyPackIT-Test1&amp;label=%24&amp;style=flat-square&amp;color=%23000&amp;labelColor=%23494949" title="Main CLI entry of the package." />

<h2>

Statistics

</h2>

<figure><table><tbody><tr><td>

<b>Project</b>

</td><td>

<img alt="Repository creation date" height="23px" src="https://img.shields.io/github/created-at/AAriam/PyPackIT-Test1?label=%F0%9F%97%93%E2%80%82Creation%20Date&amp;style=flat-square&amp;color=%230B3C75" title="Repository creation date." />&nbsp;&nbsp;<a alt="Repository contributors" href="https://github.com/AAriam/PyPackIT-Test1/graphs/contributors"><img alt="Repository contributors" height="23px" src="https://img.shields.io/github/contributors-anon/AAriam/PyPackIT-Test1?label=%F0%9F%A7%91%E2%80%8D%F0%9F%92%BB%EF%B8%8F%E2%80%82Contributors&amp;style=flat-square&amp;color=%230B3C75" title="Total number of contributors. Click to see the full list of contributors." /></a>&nbsp;&nbsp;<img alt="Programming Languages" height="23px" src="https://img.shields.io/github/languages/count/AAriam/PyPackIT-Test1?label=%F0%9F%94%A0%E2%80%82Programming%20Languages&amp;style=flat-square&amp;color=%230B3C75" title="Number of programming languages used in the project." />&nbsp;&nbsp;<img alt="Top Programming Language" height="23px" src="https://img.shields.io/github/languages/top/AAriam/PyPackIT-Test1?style=flat-square&amp;color=%230B3C75&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyB2aWV3Qm94PSIwIDAgMTExLjE2MTYgMTEyLjM4OCIgdmVyc2lvbj0iMS4wIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHhtbG5zOmNjPSJodHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9ucyMiIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4xLyIgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayI%2BCjxtZXRhZGF0YT4KPHJkZjpSREY%2BCjxjYzpXb3JrIHJkZjphYm91dD0iIj4KPGRjOmZvcm1hdD5pbWFnZS9zdmcreG1sPC9kYzpmb3JtYXQ%2BCjxkYzp0eXBlIHJkZjpyZXNvdXJjZT0iaHR0cDovL3B1cmwub3JnL2RjL2RjbWl0eXBlL1N0aWxsSW1hZ2UiLz4KPC9jYzpXb3JrPgo8L3JkZjpSREY%2BCjwvbWV0YWRhdGE%2BCjxkZWZzPgo8bGluZWFyR3JhZGllbnQgaWQ9ImIiIHgxPSIxNTAuOTYiIHgyPSIxMTIuMDMiIHkxPSIxOTIuMzUiIHkyPSIxMzcuMjciIGdyYWRpZW50VHJhbnNmb3JtPSJtYXRyaXgoLjU2MjU0IDAgMCAuNTY3OTcgLTE0Ljk5MSAtMTEuNzAyKSIgZ3JhZGllbnRVbml0cz0idXNlclNwYWNlT25Vc2UiPgo8c3RvcCBzdG9wLWNvbG9yPSIjZmZkNDNiIiBvZmZzZXQ9IjAiLz4KPHN0b3Agc3RvcC1jb2xvcj0iI2ZmZTg3MyIgb2Zmc2V0PSIxIi8%2BCjwvbGluZWFyR3JhZGllbnQ%2BCjxsaW5lYXJHcmFkaWVudCBpZD0iYSIgeDE9IjI2LjY0OSIgeDI9IjEzNS42NyIgeTE9IjIwLjYwNCIgeTI9IjExNC40IiBncmFkaWVudFRyYW5zZm9ybT0ibWF0cml4KC41NjI1NCAwIDAgLjU2Nzk3IC0xNC45OTEgLTExLjcwMikiIGdyYWRpZW50VW5pdHM9InVzZXJTcGFjZU9uVXNlIj4KPHN0b3Agc3RvcC1jb2xvcj0iIzVhOWZkNCIgb2Zmc2V0PSIwIi8%2BCjxzdG9wIHN0b3AtY29sb3I9IiMzMDY5OTgiIG9mZnNldD0iMSIvPgo8L2xpbmVhckdyYWRpZW50Pgo8L2RlZnM% " title="Percentage of the most used programming language in the repository." />&nbsp;&nbsp;<img alt="Repository Size" height="23px" src="https://img.shields.io/github/repo-size/AAriam/PyPackIT-Test1?label=%F0%9F%9A%9A%E2%80%82Repo%20Size&amp;style=flat-square&amp;color=%230B3C75" title="Total size of the repository." />&nbsp;&nbsp;<img alt="Code Size" height="23px" src="https://img.shields.io/github/languages/code-size/AAriam/PyPackIT-Test1?label=%F0%9F%9A%9B%E2%80%82Code%20Size&amp;style=flat-square&amp;color=%230B3C75" title="Code size" />

</td></tr><tr><td>

<b>Health</b>

</td><td>

<a alt="Test Coverage" href="https://codecov.io/gh/AAriam/PyPackIT-Test1"><img alt="Test Coverage" height="23px" src="https://img.shields.io/codecov/c/github/AAriam/PyPackIT-Test1?label=Test%20Coverage&amp;style=flat-square&amp;logo=codecov" title="Source code coverage by the test suite. Click to see more details on codecov.io." /></a>&nbsp;&nbsp;<a alt="SourceRank" href="https://libraries.io/pypi/PyPackIT-Test1/sourcerank"><img alt="SourceRank" height="23px" src="https://img.shields.io/librariesio/sourcerank/pypi/PyPackIT-Test1?label=SourceRank&amp;style=flat-square&amp;logoColor=%23337AB7&amp;logo=librariesdotio" title="Ranking of the source code according to libraries.io SourceRank algorithm. Click to see more details on libraries.io website." /></a>&nbsp;&nbsp;<a alt="Dependency Status" href="https://libraries.io/pypi/PyPackIT-Test1"><img alt="Dependency Status" height="23px" src="https://img.shields.io/librariesio/release/pypi/PyPackIT-Test1?label=Package%20Dependencies&amp;style=flat-square&amp;logoColor=%23337AB7&amp;logo=librariesdotio" title="Status of the project&#x27;s dependencies." /></a>&nbsp;&nbsp;<img alt="Dependency Status" height="23px" src="https://img.shields.io/librariesio/github/AAriam/PyPackIT-Test1?label=Repository%20Dependencies&amp;style=flat-square&amp;logoColor=%23337AB7&amp;logo=librariesdotio" title="Status of the project&#x27;s dependencies." />&nbsp;&nbsp;<a alt="Website Status" href="https://AAriam.github.io/PyPackIT-Test1"><img alt="Website Status" height="23px" src="https://img.shields.io/website?url=https%3A%2F%2FAAriam.github.io%2FPyPackIT-Test1&amp;up_message=online&amp;up_color=%2300802b&amp;down_message=offline&amp;down_color=%23AF1F10&amp;label=Website&amp;style=flat-square" title="Server status of our website." /></a>

</td></tr><tr><td>

<b>Standards</b>

</td><td>

<a alt="Pytest" href="https://github.com/pytest-dev/pytest/"><img alt="Pytest" height="23px" src="https://img.shields.io/static/v1?message=Pytest&amp;label=Testing&amp;style=flat-square&amp;color=%230A9EDC&amp;logoColor=%230A9EDC&amp;logo=pytest" /></a>&nbsp;&nbsp;<a alt="mypy" href="https://github.com/python/mypy"><img alt="mypy" height="23px" src="https://img.shields.io/static/v1?message=mypy&amp;label=Type%20Checking&amp;style=flat-square&amp;color=%232A6DB2&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyBkYXRhLW5hbWU9IkxheWVyIDIiIHZpZXdCb3g9IjAgMCAxODAuODcgMTc5Ljk1IiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciPgo8ZGVmcz4KPHN0eWxlPi5jbHMtMSB7CiAgICAgICAgZmlsbDogIzJhNmRiMjsKICAgICAgfQoKICAgICAgLmNscy0xLCAuY2xzLTIgewogICAgICAgIHN0cm9rZTogIzAwMDsKICAgICAgICBzdHJva2UtbWl0ZXJsaW1pdDogMTA7CiAgICAgICAgc3Ryb2tlLXdpZHRoOiA0cHg7CiAgICAgIH0KCiAgICAgIC5jbHMtMiB7CiAgICAgICAgZmlsbDogIzUwNTA1MDsKICAgICAgfTwvc3R5bGU% %2BCg%3D%3D" /></a>&nbsp;&nbsp;<a alt="Ruff" href="https://github.com/astral-sh/ruff"><img alt="Ruff" height="23px" src="https://img.shields.io/static/v1?message=Ruff&amp;label=Lint&amp;style=flat-square&amp;color=%23D7FF64&amp;logoColor=%23D7FF64&amp;logo=ruff" /></a>&nbsp;&nbsp;<a alt="CodeQL" href="https://codeql.github.com/"><img alt="CodeQL" height="23px" src="https://img.shields.io/static/v1?message=CodeQL&amp;label=Security&amp;style=flat-square&amp;color=%23181717&amp;logo=github" /></a>&nbsp;&nbsp;<a alt="Black" href="https://github.com/psf/black"><img alt="Black" height="23px" src="https://img.shields.io/static/v1?message=Black&amp;label=Code%20Style&amp;style=flat-square&amp;color=%23000&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAACoAAAAUCAYAAAD7s6%2BGAAAACXBIWXMAAADTAAAA0wHU2u75AAAEsElEQVRIib1X32sUVxT%2BtjWj3S11NiEWlgoXuwrFl8uCJPg0klJQMCzoHzAL%2FgHzkrCP8%2BaL4KBvIQ9X8cEXcSBkYWnVUQoKKTqQpxQCkxjUsDVOssk2mtCvL7mX2U2sqdoOHJi5M%2Bfc73znx5ybI4n9XrlcTgBwAAgAzrlz577rdDrfDw8PvymVSmu9329tbR2ampr6Np%2FPz8%2FMzLxqtVq%2FAUgARCTjfW8MIPchoLlcrgqgeurUqZ9GRkYOnTlzprO5ufnN7Ows5ubm2o8fP94CgFar9c3q6mpR65VKpeV8Pr8JAKdPnz5QKBQOOI5TtG17ZW5u7u3Dhw8H79y58zOAEEBIMv1HICR3CQAbgF8ul5cmJydbURSt1mq116VS6RUAfqpYltUZGhp6PjEx8bbZbC5Vq1UCUACcvfCQ3A0UgD8yMrLeaDRa4%2BPj7cOHD6%2FoDYQQdBynS1zX%2FWTgQ0NDz%2B%2Fevbt%2B6dKlzg7D4r1AAYiBgYHZW7duLY%2BPj7e1EcdxGIYh4zimUoq%2B7zMIApJkmqaM45i2bX8yWAA8efLk8vT09JtKpdIGUN0FFICsVCrt6enpN8ViMdWKSikqpSiEoO%2F7tG2btm0b0FJKkqTneZ8FqJbr16%2Bv7bDrZoiE3d%2Ffv%2FjkyZO3lmV1siB1WG3bZpqmFEIwjmMmSWJSgSR93zffOY7z0Qw7jkMhBAGwVqut7IB1NFD%2F0aNHfxw8ePBPrSClpFLKGAiCgEophmFIksaBMAyNA9nnjwGqlCJJSinN2s2bN9f6%2B%2FsXSQKVSqVdq9Ve93oWBAEB0PM8kjR5mSQJXddlFEWM49gYdl23y4l%2FI9k9suvFYjGt1%2BsrABzU6%2FWVcrmc9CoHQcAoihhFET3PY5qmXWGO45gkKYSglJJpmjKKIqMvpaSU0qTD%2B0BWq1VTmHtFotlsvgTg7wIqhKDneV1Kvu9TXzrMek2HW7%2BzbZtRFJEkr169yjRNTU5nnXdd1zioC1J3lT2B9oZeK2ZZSJKEJM0m2bUs07ojkOT58%2Bd5%2BfJlkw46B8MwpOd59DzP2NB2epnvCn1vMelc0Yxq5uI4ZhiGplXpNZ27UkrDpOd5tCyLz549Y5IkVEoZB3RKhGHIKIqYpqnJbyll1943btxom2ICYA8MDMw%2BePCgbVlWJwgChmHIarVqWFBK0bZtKqUMMN3oHccxbOu%2BWq%2FXeeXKFcOU67omF7P2dSQ00GxxTkxMbF64cGHDtKcdtPLYsWNrU1NT6dGjR1vZX2Vvgut1%2FdzbO3Vx6YLSOa2%2F0%2B%2F0Hvpe2%2Bvr69vYs%2BEzM4gMDg7%2BOjk52RobG1vPNv%2F%2FS0ZHR5cbjUZr5xfaNaDsNZR4lUql3Ww2l8bGxtazQ8l%2FIZZldUZHR1tPnz7VLCoA9i5cvQuaXewe81Y%2B55h39uzZ59euXWvfvn17aScFFPaYmrTse3Aul8s%2FXrx4MS%2Bl7JDMz8%2FPH3jx4sX6%2Ffv3%2F9re3t4GgMXFxSPv3r37CgDK5fKCtnH8%2BPE%2BIcSXw8PDhUKh0F5YWPii0Wh8fe%2FevV%2Bwz8H5g0B7QAtkjiInTpw4UiqVfgCA3uOIPoYAwMbGxsuZmZnfAcT4yKPI33h1eJ0JUuCWAAAAAElFTkSuQmCC" /></a>

</td></tr><tr><td>

<b>Downloads</b>

</td><td>

<a alt="PyPI Downloads" href="https://pepy.tech/projects/PyPackIT-Test1"><img alt="PyPI Downloads" height="23px" src="https://img.shields.io/pepy/dt/PyPackIT-Test1?label=PyPI&amp;style=flat-square&amp;color=%230B3C75&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAC4AAAApCAYAAABKvBuPAAAACXBIWXMAAAewAAAHsAHUgoNiAAAIn0lEQVRYhcWZbUxb1xnHf7av7%2FX19cU2xoDBBEoJBAxJ6FJIaLYubZdKrdalW6Zu3bRN2qYp1bRqm9QvlaapUrcvU7Sqa%2BmHfli%2BbFNftGpV05ZV2Zq2NLRpIC%2BU0qQ0GBJejI2N8TV%2BvftAcCDYYCDt%2FpLl63v%2Bz3N%2Bvr7nnOf4ous6%2F8%2FX03999fUX3jjVtdE4g67rfNn64zMvPjUaiv1gLk3px1fnDNvKFNpqy6PbytSPf3H463uLyfGlgf%2Fh6X8cmZpP%2Fja4kL1lJKgZtUQ6r29XrUuvr3SGat32137yrTt%2BXCjfFwr%2BxJ%2F%2F3hVNZp6b0tLNoiQKjdVlzC%2Bk%2BNeHnxWMUSSRzmYvCd1E5y3Onh%2Fdv%2FfefD7hiwB%2B%2FOjfTk1FEy3TC1nVPxPLnT89MkOZKnGnz0tTlYP3hyc5758BYL%2BvBrMkMzaboHdUA%2BBr28u0Qn3cVPDf%2F%2BWFjw2i2Pza0ExBz0w0wduD47w9OM7dO7fx0x07GRif5%2FRVDUgV3ddNBZ%2BNLohvj0zSXGVHEU3EM1kGx8IrPN6yEhq8buIZA2cmNWSbzuBE%2FgtbLn56aHrg9XHNuP3lup3ff%2FQLA1%2FS0NUIAFZJwFdtx11iQVYUIkkTo6E4p0Zj62RYlJkw5cnnqzMov4p89NovY6Y9g0mTp7uu7aHumwZ%2B8mTfWyVW6Zbl57REmsErEbgS4cDues6MRTeV20QMe%2Bak0Z452RYQHnx2bCBw1LgV2BMnep%2F64IOB8cuXRzMdHa13i6J53Xy%2FfqAdj1PZUD9zxtsJiYeZk76J23wBRQjpm7riZ84M%2BG021dPZ2SqYTKai4372DR8P7d%2BOx2nlsWPvren1OiTCWR8R6RA24wgmzq5o3xS4u8xRk0plmJoKUF7uRhCKg2%2BscjC%2FkOL5fw%2FmbZfNRnZUKFSqMiFtAVlMYzfm924KXBBMqOrizx2LRYlEYsiyBYPBsGbcY8few%2BNUmJi9Pjh1XcfnUai2W0HX6RmeARbHwgM7SwszbBS6p%2BedI22tdbnPkihycczPu%2BdHUa0K9%2B2u48J4gOULz3ItQXsdEo1uG9vLZHo%2FCzE4UdxMsyHw48f%2F26Wq1qMVFa6v7NvXJsxHo5y%2FOM775%2FwMXQkzHIixvPbwOKwc7txOYE5jcHyGmWgCAJci0FCmUO2wcNo%2Fx4mLQYyCkXgquyHodcFPnux7y25XO7q62lSLxZI7f%2ByNft4dnmY8lH%2FhmAhrvNR3EYB9jZUcbHMgWQSyCPSNRmA0smHQ5cpmMRcEHxg4F6isdJapqpXl0AD9o7MYjQbaaxyIFjN9FwOr4vftqEK2Kvhnk%2FQPhXnkQC19%2FYVLgWKk6VWEUm1ohlpTQfD5aDxSV%2BspAwgEAiSTGUpKbKiqDQD%2FTAz%2FNW9zlR2XImIyC8iKjUAsQ%2F%2BExtIg24qSupNQ2sdCtgKX%2BTRe8U1ChjsXirrHVdviDBKZizEycmVV%2B9ISv6feRd%2FE1mFls5F2rw2rKBHJNFBpfneVpyjwkc%2BvYjaL1NSUU1HhhuPntwyXTz6PQku5mX1Vn9NV1s2Y4ee49Q%2FzeguCm0wm16h%2FGrfbSUtLQ1Edb2QVXZJihgdaHbS45znkPVp0XEFwgwGbvUQmHo8TjZpy9%2FZaMmAC1t9RuRSB1kob7Z4F2j3DNFleLBp4SQXBU%2BkMDocKQDab5eqVSTCA02nfcCcARgy0e1Vu9%2Bp0lJ%2Bh1f4fAIKGA8V81%2BLBjQZDrs1oNFJaWgJAIpmgvdaNzSIxdCVEoU3vknweheYKGyWyge4Df8rjWLtMuFEZZOIpm2UF%2BIkTvU%2FZbNbvlJc7PZJkzhsoiSL9owGGr0a4b3ctug7js1HO%2B0M5j9ch0VJZgioZefnsFIMTMZ6sKVx3FCNNryKcbiNpbqKk9s6k0NPzzhFFkY%2B43c7m5WXqTCC0Tio4PjCaOz7ceStGo4H6aoXT%2Fjl6Plm9KG1UWUxMp%2FaimXbiqruLKrsbgFAokhXq6yueFUWR0tLSTc0KS3qp7zP21Lu4MDu%2FJdgMMuF0E9FMA0mxlNrbnszrExSrjCxbcuWpqlpxOp1b6nwzCmebmU9vQ9ehRnoTlzDAmPS7gv7cPS6JIuVuEVhc4sGox%2BMLBlm2FIpdnaxwBZFXml5FNO0mmjlEnfQKDnGo6Ni8e0TVppBOpwxgYGIyTCgUI51ee%2FZYI90KJXUn06lOLicOkdHNqOZp6qRXrhtK7gCxct08a14iWZaQZQmAcEQjHo9hU0Ss0saurEsRSGUk%2FIn7kE0Bys19ubYg9deNyi6ofQJSU%2FDJw5sEv2Eb5rBbcVxbex7ev4MmT4DB8ZkV0%2BCN8nkUbi1T2dPgptkdoyZ%2BPF9H1w9L9i%2B%2BTx0rmFPTNMLhaGJTe87WhnJub9sGQM%2Bpiwz5Z%2Fno8iRwbQ73lNBSZed7996Wixm7dHr9xBPPwOybsHBpxelkMkkoFI1Ho9q5RCL1m9bW%2Bl4hnc5shj2ng3u3c3AvBGZjnLs0SVd7Mx735soCIAed1J0kkxn90qXxC4lEstvnq%2B%2BurHTlbEIwtPCIpmUft1oFj6JIRqNxc%2F8RuZ0K7Q3urUEDwfTubDTjndCy3pdbOu56tJBP2L17RzfQDXD27Kf%2FtMrmr9psYikbLSI2KV3XiWbq9HC6MaRlqweaOn54j2v9sJWDc9euxgcB%2BvuHu8xmy6szwXmrqooWSRSLgjALxfkgtyVLRHRfOpVqOdi699u9RQffCL6k9vamXsAFi19CkkzPWa3mZpsiCoJQeDyvV51eW86zs%2BnGwUTW1e3rPNy9%2FoydXxt6lDIw8MkR2SI%2BLpiz1U6Hyo3jYS66wLZtNavigsEQwenxVDo63N3S8d2C9%2B1GtOlnQOfPfXrMYjHfb7OJpbIsGmAluKZpBIPRoKbFB5qa6u65GbDLteWHV4vjwXjUYhFaTEZdla32FfPtTeJcpf8Bf0u4HEa2VhUAAAAASUVORK5CYII%3D" title="Total number of downloads of all releases from PyPI. Click to see more details on pypi.org." /></a>&nbsp;<a alt="PyPI Downloads" href="https://pepy.tech/projects/PyPackIT-Test1"><img alt="PyPI Downloads" height="23px" src="https://img.shields.io/pypi/dm/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%230B3C75" title="Number of downloads of all releases from PyPI, per month. Click to see more details on PyPI." /></a>&nbsp;<a alt="PyPI Downloads" href="https://pepy.tech/projects/PyPackIT-Test1"><img alt="PyPI Downloads" height="23px" src="https://img.shields.io/pypi/dw/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%230B3C75" title="Number of downloads of all releases from PyPI, per week. Click to see more details on PyPI." /></a>&nbsp;<a alt="PyPI Downloads" href="https://pepy.tech/projects/PyPackIT-Test1"><img alt="PyPI Downloads" height="23px" src="https://img.shields.io/pypi/dd/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%230B3C75" title="Number of downloads of all releases from PyPI, per day. Click to see more details on PyPI." /></a>&nbsp;&nbsp;<a alt="GitHub Downloads" href="https://github.com/AAriam/PyPackIT-Test1/releases"><img alt="GitHub Downloads" height="23px" src="https://img.shields.io/github/downloads/AAriam/PyPackIT-Test1/total?label=GitHub&amp;style=flat-square&amp;color=%230B3C75&amp;logo=github" title="Number of downloads of all releases from GitHub." /></a>

</td></tr><tr><td>

<b>Users</b>

</td><td>

<a alt="Dependents" href="https://libraries.io/pypi/PyPackIT-Test1"><img alt="Dependents" height="23px" src="https://img.shields.io/librariesio/dependents/pypi/PyPackIT-Test1?label=Dependent%20Packages&amp;style=flat-square&amp;color=%230B3C75&amp;logoColor=%23337AB7&amp;logo=librariesdotio" title="Number of packages that depend on us." /></a>&nbsp;&nbsp;<a alt="Dependents" href="https://libraries.io/pypi/PyPackIT-Test1"><img alt="Dependents" height="23px" src="https://img.shields.io/librariesio/dependent-repos/pypi/PyPackIT-Test1?label=Dependent%20Repositories&amp;style=flat-square&amp;color=%230B3C75&amp;logoColor=%23337AB7&amp;logo=librariesdotio" title="Number of repositories that depend on us." /></a>

</td></tr><tr><td>

<b>Issues</b>

</td><td>

<img alt="Open Issues Count" height="23px" src="https://img.shields.io/github/issues/AAriam/PyPackIT-Test1?label=Total&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open issues." /><img alt="Closed Issues Count" height="23px" src="https://img.shields.io/github/issues-closed/AAriam/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed issues." />&nbsp;&nbsp;<img alt="Open Issues Count" height="23px" src="https://img.shields.io/github/issues/AAriam/PyPackIT-Test1/type: Fix?label=%F0%9F%90%9E%E2%80%82Bug%20Fixes&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open issues with label type: Fix." /><img alt="Closed Issues Count" height="23px" src="https://img.shields.io/github/issues-closed/AAriam/PyPackIT-Test1/type: Fix?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed issues with label type: Fix." />&nbsp;&nbsp;<img alt="Open Issues Count" height="23px" src="https://img.shields.io/github/issues/AAriam/PyPackIT-Test1/type: Feat?label=%E2%9C%A8%E2%80%82New%20Features&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open issues with label type: Feat." /><img alt="Closed Issues Count" height="23px" src="https://img.shields.io/github/issues-closed/AAriam/PyPackIT-Test1/type: Feat?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed issues with label type: Feat." />&nbsp;&nbsp;<img alt="Open Issues Count" height="23px" src="https://img.shields.io/github/issues/AAriam/PyPackIT-Test1/type: Change?label=%F0%9F%92%A5%E2%80%82Breaking%20Changes&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open issues with label type: Change." /><img alt="Closed Issues Count" height="23px" src="https://img.shields.io/github/issues-closed/AAriam/PyPackIT-Test1/type: Change?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed issues with label type: Change." />&nbsp;&nbsp;

</td></tr><tr><td>

<b>PRs</b>

</td><td>

<img alt="Open Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr/AAriam/PyPackIT-Test1?label=Total&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open pulls." /><img alt="Closed Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr-closed/AAriam/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed pulls." />&nbsp;&nbsp;<img alt="Open Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr/AAriam/PyPackIT-Test1/type: Fix?label=%F0%9F%90%9E%E2%80%82Bug%20Fixes&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open pulls with label type: Fix." /><img alt="Closed Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr-closed/AAriam/PyPackIT-Test1/type: Fix?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed pulls with label type: Fix." />&nbsp;&nbsp;<img alt="Open Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr/AAriam/PyPackIT-Test1/type: Feat?label=%E2%9C%A8%E2%80%82New%20Features&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open pulls with label type: Feat." /><img alt="Closed Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr-closed/AAriam/PyPackIT-Test1/type: Feat?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed pulls with label type: Feat." />&nbsp;&nbsp;<img alt="Open Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr/AAriam/PyPackIT-Test1/type: Change?label=%F0%9F%92%A5%E2%80%82Breaking%20Changes&amp;style=flat-square&amp;color=%23AF1F10" title="Number of open pulls with label type: Change." /><img alt="Closed Pulls Count" height="23px" src="https://img.shields.io/github/issues-pr-closed/AAriam/PyPackIT-Test1/type: Change?label=&amp;style=flat-square&amp;color=%2300802B" title="Number of closed pulls with label type: Change." />&nbsp;&nbsp;

</td></tr><tr><td>

<b>Commits</b>

</td><td>

<a alt="Total commits" href="https://github.com/AAriam/PyPackIT-Test1/commits"><img alt="Total commits" height="23px" src="https://img.shields.io/github/commit-activity/t/AAriam/PyPackIT-Test1?label=Total&amp;style=flat-square&amp;color=%230B3C75&amp;logoColor=%23F05032&amp;logo=git" title="Total number of commits . Click to see the full list of commits." /></a>&nbsp;&nbsp;<a alt="Commits/Year" href="https://github.com/AAriam/PyPackIT-Test1/commits"><img alt="Commits/Year" height="23px" src="https://img.shields.io/github/commit-activity/y/AAriam/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%230B3C75" title="Number of commits in the last year. Click to see the full list of commits." /></a>&nbsp;&nbsp;<a alt="Commits/Month" href="https://github.com/AAriam/PyPackIT-Test1/commits"><img alt="Commits/Month" height="23px" src="https://img.shields.io/github/commit-activity/m/AAriam/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%230B3C75" title="Number of commits in the last month. Click to see the full list of commits." /></a>&nbsp;&nbsp;<a alt="Commits/Week" href="https://github.com/AAriam/PyPackIT-Test1/commits"><img alt="Commits/Week" height="23px" src="https://img.shields.io/github/commit-activity/w/AAriam/PyPackIT-Test1?label=&amp;style=flat-square&amp;color=%230B3C75" title="Number of commits in the last week. Click to see the full list of commits." /></a>&nbsp;&nbsp;<a alt="Commits since latest release" href="https://github.com/AAriam/PyPackIT-Test1/commits"><img alt="Commits since latest release" height="23px" src="https://img.shields.io/github/commits-since/AAriam/PyPackIT-Test1/latest?include_prereleases&amp;sort=date&amp;label=Since%20Latest%20Release&amp;style=flat-square&amp;color=%230B3C75" title="Number of commits since the latest release. Click to see the full list of commits." /></a>&nbsp;&nbsp;<a alt="Last commit" href="https://github.com/AAriam/PyPackIT-Test1/commits"><img alt="Last commit" height="23px" src="https://img.shields.io/github/last-commit/AAriam/PyPackIT-Test1?display_timestamp=author&amp;label=Last&amp;style=flat-square&amp;color=%230B3C75" title="Time of the last commit. Click to see the full list of commits." /></a>

</td></tr><tr><td>

<b>Discussions</b>

</td><td>

<img alt="Discussions Search Hits (category:&quot;Announcements&quot;)" height="23px" src="https://img.shields.io/github/discussions-search/AAriam/PyPackIT-Test1?query=category%3A%22Announcements%22&amp;label=%F0%9F%93%A3%E2%80%82Announcements&amp;style=flat-square&amp;color=%230B3C75" title="Updates from maintainers" />&nbsp;&nbsp;<img alt="Discussions Search Hits (category:&quot;General&quot;)" height="23px" src="https://img.shields.io/github/discussions-search/AAriam/PyPackIT-Test1?query=category%3A%22General%22&amp;label=%F0%9F%92%AC%E2%80%82General&amp;style=flat-square&amp;color=%230B3C75" title="Chat about anything and everything here" />&nbsp;&nbsp;<img alt="Discussions Search Hits (category:&quot;Ideas&quot;)" height="23px" src="https://img.shields.io/github/discussions-search/AAriam/PyPackIT-Test1?query=category%3A%22Ideas%22&amp;label=%F0%9F%92%A1%E2%80%82Ideas&amp;style=flat-square&amp;color=%230B3C75" title="Share ideas for new features" />&nbsp;&nbsp;<img alt="Discussions Search Hits (category:&quot;Polls&quot;)" height="23px" src="https://img.shields.io/github/discussions-search/AAriam/PyPackIT-Test1?query=category%3A%22Polls%22&amp;label=%F0%9F%97%B3%EF%B8%8F%E2%80%82Polls&amp;style=flat-square&amp;color=%230B3C75" title="Take a vote from the community" />&nbsp;&nbsp;<img alt="Discussions Search Hits (category:&quot;Q&amp;A&quot;)" height="23px" src="https://img.shields.io/github/discussions-search/AAriam/PyPackIT-Test1?query=category%3A%22Q%26A%22&amp;label=%F0%9F%99%8F%E2%80%82Q%26A&amp;style=flat-square&amp;color=%230B3C75" title="Ask the community for help" />&nbsp;&nbsp;<img alt="Discussions Search Hits (category:&quot;Show and tell&quot;)" height="23px" src="https://img.shields.io/github/discussions-search/AAriam/PyPackIT-Test1?query=category%3A%22Show%20and%20tell%22&amp;label=%F0%9F%99%8C%E2%80%82Show%20and%20tell&amp;style=flat-square&amp;color=%230B3C75" title="Show off something you&#x27;ve made" />

</td></tr><tr><td>

<b>Community</b>

</td><td>

<img alt="Forks" height="23px" src="https://img.shields.io/github/forks/AAriam/PyPackIT-Test1?label=Forks&amp;style=flat-square&amp;color=%230B3C75&amp;logo=github" title="Number of repository forks" />&nbsp;&nbsp;<img alt="Stars" height="23px" src="https://img.shields.io/github/stars/AAriam/PyPackIT-Test1?label=Stars&amp;style=flat-square&amp;color=%230B3C75&amp;logo=github" title="Number of repository stars" />&nbsp;&nbsp;<img alt="Repository Watchers" height="23px" src="https://img.shields.io/github/watchers/AAriam/PyPackIT-Test1?label=Watchers&amp;style=flat-square&amp;color=%230B3C75&amp;logo=github" title="Number of repository watchers" />

</td></tr><tr><td>

<b>DevOps</b>

</td><td>

<a alt="Workflow Status" href="https://github.com/AAriam/PyPackIT-Test1/actions/workflows/main.yaml"><img alt="Workflow Status" height="23px" src="https://img.shields.io/github/actions/workflow/status/AAriam/PyPackIT-Test1/main.yaml?label=CI&amp;style=flat-square&amp;logo=github" title="Status of the GitHub Actions workflow &#x27;main.yaml&#x27;.Click to see more details in the Actions section of the repository." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/PyPI (PyPackIT-Test1)"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/PyPI (PyPackIT-Test1)?label=CD%20PyPI%20%28PyPackIT-Test1%29&amp;style=flat-square&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAC4AAAApCAYAAABKvBuPAAAACXBIWXMAAAewAAAHsAHUgoNiAAAIn0lEQVRYhcWZbUxb1xnHf7av7%2FX19cU2xoDBBEoJBAxJ6FJIaLYubZdKrdalW6Zu3bRN2qYp1bRqm9QvlaapUrcvU7Sqa%2BmHfli%2BbFNftGpV05ZV2Zq2NLRpIC%2BU0qQ0GBJejI2N8TV%2BvftAcCDYYCDt%2FpLl63v%2Bz3N%2Bvr7nnOf4ous6%2F8%2FX03999fUX3jjVtdE4g67rfNn64zMvPjUaiv1gLk3px1fnDNvKFNpqy6PbytSPf3H463uLyfGlgf%2Fh6X8cmZpP%2Fja4kL1lJKgZtUQ6r29XrUuvr3SGat32137yrTt%2BXCjfFwr%2BxJ%2F%2F3hVNZp6b0tLNoiQKjdVlzC%2Bk%2BNeHnxWMUSSRzmYvCd1E5y3Onh%2Fdv%2FfefD7hiwB%2B%2FOjfTk1FEy3TC1nVPxPLnT89MkOZKnGnz0tTlYP3hyc5758BYL%2BvBrMkMzaboHdUA%2BBr28u0Qn3cVPDf%2F%2BWFjw2i2Pza0ExBz0w0wduD47w9OM7dO7fx0x07GRif5%2FRVDUgV3ddNBZ%2BNLohvj0zSXGVHEU3EM1kGx8IrPN6yEhq8buIZA2cmNWSbzuBE%2FgtbLn56aHrg9XHNuP3lup3ff%2FQLA1%2FS0NUIAFZJwFdtx11iQVYUIkkTo6E4p0Zj62RYlJkw5cnnqzMov4p89NovY6Y9g0mTp7uu7aHumwZ%2B8mTfWyVW6Zbl57REmsErEbgS4cDues6MRTeV20QMe%2Bak0Z452RYQHnx2bCBw1LgV2BMnep%2F64IOB8cuXRzMdHa13i6J53Xy%2FfqAdj1PZUD9zxtsJiYeZk76J23wBRQjpm7riZ84M%2BG021dPZ2SqYTKai4372DR8P7d%2BOx2nlsWPvren1OiTCWR8R6RA24wgmzq5o3xS4u8xRk0plmJoKUF7uRhCKg2%2BscjC%2FkOL5fw%2FmbZfNRnZUKFSqMiFtAVlMYzfm924KXBBMqOrizx2LRYlEYsiyBYPBsGbcY8few%2BNUmJi9Pjh1XcfnUai2W0HX6RmeARbHwgM7SwszbBS6p%2BedI22tdbnPkihycczPu%2BdHUa0K9%2B2u48J4gOULz3ItQXsdEo1uG9vLZHo%2FCzE4UdxMsyHw48f%2F26Wq1qMVFa6v7NvXJsxHo5y%2FOM775%2FwMXQkzHIixvPbwOKwc7txOYE5jcHyGmWgCAJci0FCmUO2wcNo%2Fx4mLQYyCkXgquyHodcFPnux7y25XO7q62lSLxZI7f%2ByNft4dnmY8lH%2FhmAhrvNR3EYB9jZUcbHMgWQSyCPSNRmA0smHQ5cpmMRcEHxg4F6isdJapqpXl0AD9o7MYjQbaaxyIFjN9FwOr4vftqEK2Kvhnk%2FQPhXnkQC19%2FYVLgWKk6VWEUm1ohlpTQfD5aDxSV%2BspAwgEAiSTGUpKbKiqDQD%2FTAz%2FNW9zlR2XImIyC8iKjUAsQ%2F%2BExtIg24qSupNQ2sdCtgKX%2BTRe8U1ChjsXirrHVdviDBKZizEycmVV%2B9ISv6feRd%2FE1mFls5F2rw2rKBHJNFBpfneVpyjwkc%2BvYjaL1NSUU1HhhuPntwyXTz6PQku5mX1Vn9NV1s2Y4ee49Q%2FzeguCm0wm16h%2FGrfbSUtLQ1Edb2QVXZJihgdaHbS45znkPVp0XEFwgwGbvUQmHo8TjZpy9%2FZaMmAC1t9RuRSB1kob7Z4F2j3DNFleLBp4SQXBU%2BkMDocKQDab5eqVSTCA02nfcCcARgy0e1Vu9%2Bp0lJ%2Bh1f4fAIKGA8V81%2BLBjQZDrs1oNFJaWgJAIpmgvdaNzSIxdCVEoU3vknweheYKGyWyge4Df8rjWLtMuFEZZOIpm2UF%2BIkTvU%2FZbNbvlJc7PZJkzhsoiSL9owGGr0a4b3ctug7js1HO%2B0M5j9ch0VJZgioZefnsFIMTMZ6sKVx3FCNNryKcbiNpbqKk9s6k0NPzzhFFkY%2B43c7m5WXqTCC0Tio4PjCaOz7ceStGo4H6aoXT%2Fjl6Plm9KG1UWUxMp%2FaimXbiqruLKrsbgFAokhXq6yueFUWR0tLSTc0KS3qp7zP21Lu4MDu%2FJdgMMuF0E9FMA0mxlNrbnszrExSrjCxbcuWpqlpxOp1b6nwzCmebmU9vQ9ehRnoTlzDAmPS7gv7cPS6JIuVuEVhc4sGox%2BMLBlm2FIpdnaxwBZFXml5FNO0mmjlEnfQKDnGo6Ni8e0TVppBOpwxgYGIyTCgUI51ee%2FZYI90KJXUn06lOLicOkdHNqOZp6qRXrhtK7gCxct08a14iWZaQZQmAcEQjHo9hU0Ss0saurEsRSGUk%2FIn7kE0Bys19ubYg9deNyi6ofQJSU%2FDJw5sEv2Eb5rBbcVxbex7ev4MmT4DB8ZkV0%2BCN8nkUbi1T2dPgptkdoyZ%2BPF9H1w9L9i%2B%2BTx0rmFPTNMLhaGJTe87WhnJub9sGQM%2Bpiwz5Z%2Fno8iRwbQ73lNBSZed7996Wixm7dHr9xBPPwOybsHBpxelkMkkoFI1Ho9q5RCL1m9bW%2Bl4hnc5shj2ng3u3c3AvBGZjnLs0SVd7Mx735soCIAed1J0kkxn90qXxC4lEstvnq%2B%2BurHTlbEIwtPCIpmUft1oFj6JIRqNxc%2F8RuZ0K7Q3urUEDwfTubDTjndCy3pdbOu56tJBP2L17RzfQDXD27Kf%2FtMrmr9psYikbLSI2KV3XiWbq9HC6MaRlqweaOn54j2v9sJWDc9euxgcB%2BvuHu8xmy6szwXmrqooWSRSLgjALxfkgtyVLRHRfOpVqOdi699u9RQffCL6k9vamXsAFi19CkkzPWa3mZpsiCoJQeDyvV51eW86zs%2BnGwUTW1e3rPNy9%2FoydXxt6lDIw8MkR2SI%2BLpiz1U6Hyo3jYS66wLZtNavigsEQwenxVDo63N3S8d2C9%2B1GtOlnQOfPfXrMYjHfb7OJpbIsGmAluKZpBIPRoKbFB5qa6u65GbDLteWHV4vjwXjUYhFaTEZdla32FfPtTeJcpf8Bf0u4HEa2VhUAAAAASUVORK5CYII%3D" title="Deployment status for &#x27;PyPI (PyPackIT-Test1)&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/PyPI (PyPackIT-Test1-TestSuite)"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/PyPI (PyPackIT-Test1-TestSuite)?label=CD%20PyPI%20%28PyPackIT-Test1-TestSuite%29&amp;style=flat-square&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAC4AAAApCAYAAABKvBuPAAAACXBIWXMAAAewAAAHsAHUgoNiAAAIn0lEQVRYhcWZbUxb1xnHf7av7%2FX19cU2xoDBBEoJBAxJ6FJIaLYubZdKrdalW6Zu3bRN2qYp1bRqm9QvlaapUrcvU7Sqa%2BmHfli%2BbFNftGpV05ZV2Zq2NLRpIC%2BU0qQ0GBJejI2N8TV%2BvftAcCDYYCDt%2FpLl63v%2Bz3N%2Bvr7nnOf4ous6%2F8%2FX03999fUX3jjVtdE4g67rfNn64zMvPjUaiv1gLk3px1fnDNvKFNpqy6PbytSPf3H463uLyfGlgf%2Fh6X8cmZpP%2Fja4kL1lJKgZtUQ6r29XrUuvr3SGat32137yrTt%2BXCjfFwr%2BxJ%2F%2F3hVNZp6b0tLNoiQKjdVlzC%2Bk%2BNeHnxWMUSSRzmYvCd1E5y3Onh%2Fdv%2FfefD7hiwB%2B%2FOjfTk1FEy3TC1nVPxPLnT89MkOZKnGnz0tTlYP3hyc5758BYL%2BvBrMkMzaboHdUA%2BBr28u0Qn3cVPDf%2F%2BWFjw2i2Pza0ExBz0w0wduD47w9OM7dO7fx0x07GRif5%2FRVDUgV3ddNBZ%2BNLohvj0zSXGVHEU3EM1kGx8IrPN6yEhq8buIZA2cmNWSbzuBE%2FgtbLn56aHrg9XHNuP3lup3ff%2FQLA1%2FS0NUIAFZJwFdtx11iQVYUIkkTo6E4p0Zj62RYlJkw5cnnqzMov4p89NovY6Y9g0mTp7uu7aHumwZ%2B8mTfWyVW6Zbl57REmsErEbgS4cDues6MRTeV20QMe%2Bak0Z452RYQHnx2bCBw1LgV2BMnep%2F64IOB8cuXRzMdHa13i6J53Xy%2FfqAdj1PZUD9zxtsJiYeZk76J23wBRQjpm7riZ84M%2BG021dPZ2SqYTKai4372DR8P7d%2BOx2nlsWPvren1OiTCWR8R6RA24wgmzq5o3xS4u8xRk0plmJoKUF7uRhCKg2%2BscjC%2FkOL5fw%2FmbZfNRnZUKFSqMiFtAVlMYzfm924KXBBMqOrizx2LRYlEYsiyBYPBsGbcY8few%2BNUmJi9Pjh1XcfnUai2W0HX6RmeARbHwgM7SwszbBS6p%2BedI22tdbnPkihycczPu%2BdHUa0K9%2B2u48J4gOULz3ItQXsdEo1uG9vLZHo%2FCzE4UdxMsyHw48f%2F26Wq1qMVFa6v7NvXJsxHo5y%2FOM775%2FwMXQkzHIixvPbwOKwc7txOYE5jcHyGmWgCAJci0FCmUO2wcNo%2Fx4mLQYyCkXgquyHodcFPnux7y25XO7q62lSLxZI7f%2ByNft4dnmY8lH%2FhmAhrvNR3EYB9jZUcbHMgWQSyCPSNRmA0smHQ5cpmMRcEHxg4F6isdJapqpXl0AD9o7MYjQbaaxyIFjN9FwOr4vftqEK2Kvhnk%2FQPhXnkQC19%2FYVLgWKk6VWEUm1ohlpTQfD5aDxSV%2BspAwgEAiSTGUpKbKiqDQD%2FTAz%2FNW9zlR2XImIyC8iKjUAsQ%2F%2BExtIg24qSupNQ2sdCtgKX%2BTRe8U1ChjsXirrHVdviDBKZizEycmVV%2B9ISv6feRd%2FE1mFls5F2rw2rKBHJNFBpfneVpyjwkc%2BvYjaL1NSUU1HhhuPntwyXTz6PQku5mX1Vn9NV1s2Y4ee49Q%2FzeguCm0wm16h%2FGrfbSUtLQ1Edb2QVXZJihgdaHbS45znkPVp0XEFwgwGbvUQmHo8TjZpy9%2FZaMmAC1t9RuRSB1kob7Z4F2j3DNFleLBp4SQXBU%2BkMDocKQDab5eqVSTCA02nfcCcARgy0e1Vu9%2Bp0lJ%2Bh1f4fAIKGA8V81%2BLBjQZDrs1oNFJaWgJAIpmgvdaNzSIxdCVEoU3vknweheYKGyWyge4Df8rjWLtMuFEZZOIpm2UF%2BIkTvU%2FZbNbvlJc7PZJkzhsoiSL9owGGr0a4b3ctug7js1HO%2B0M5j9ch0VJZgioZefnsFIMTMZ6sKVx3FCNNryKcbiNpbqKk9s6k0NPzzhFFkY%2B43c7m5WXqTCC0Tio4PjCaOz7ceStGo4H6aoXT%2Fjl6Plm9KG1UWUxMp%2FaimXbiqruLKrsbgFAokhXq6yueFUWR0tLSTc0KS3qp7zP21Lu4MDu%2FJdgMMuF0E9FMA0mxlNrbnszrExSrjCxbcuWpqlpxOp1b6nwzCmebmU9vQ9ehRnoTlzDAmPS7gv7cPS6JIuVuEVhc4sGox%2BMLBlm2FIpdnaxwBZFXml5FNO0mmjlEnfQKDnGo6Ni8e0TVppBOpwxgYGIyTCgUI51ee%2FZYI90KJXUn06lOLicOkdHNqOZp6qRXrhtK7gCxct08a14iWZaQZQmAcEQjHo9hU0Ss0saurEsRSGUk%2FIn7kE0Bys19ubYg9deNyi6ofQJSU%2FDJw5sEv2Eb5rBbcVxbex7ev4MmT4DB8ZkV0%2BCN8nkUbi1T2dPgptkdoyZ%2BPF9H1w9L9i%2B%2BTx0rmFPTNMLhaGJTe87WhnJub9sGQM%2Bpiwz5Z%2Fno8iRwbQ73lNBSZed7996Wixm7dHr9xBPPwOybsHBpxelkMkkoFI1Ho9q5RCL1m9bW%2Bl4hnc5shj2ng3u3c3AvBGZjnLs0SVd7Mx735soCIAed1J0kkxn90qXxC4lEstvnq%2B%2BurHTlbEIwtPCIpmUft1oFj6JIRqNxc%2F8RuZ0K7Q3urUEDwfTubDTjndCy3pdbOu56tJBP2L17RzfQDXD27Kf%2FtMrmr9psYikbLSI2KV3XiWbq9HC6MaRlqweaOn54j2v9sJWDc9euxgcB%2BvuHu8xmy6szwXmrqooWSRSLgjALxfkgtyVLRHRfOpVqOdi699u9RQffCL6k9vamXsAFi19CkkzPWa3mZpsiCoJQeDyvV51eW86zs%2BnGwUTW1e3rPNy9%2FoydXxt6lDIw8MkR2SI%2BLpiz1U6Hyo3jYS66wLZtNavigsEQwenxVDo63N3S8d2C9%2B1GtOlnQOfPfXrMYjHfb7OJpbIsGmAluKZpBIPRoKbFB5qa6u65GbDLteWHV4vjwXjUYhFaTEZdla32FfPtTeJcpf8Bf0u4HEa2VhUAAAAASUVORK5CYII%3D" title="Deployment status for &#x27;PyPI (PyPackIT-Test1-TestSuite)&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/TestPyPI (PyPackIT-Test1)"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/TestPyPI (PyPackIT-Test1)?label=CD%20TestPyPI%20%28PyPackIT-Test1%29&amp;style=flat-square&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAC4AAAApCAYAAABKvBuPAAAACXBIWXMAAAewAAAHsAHUgoNiAAAIn0lEQVRYhcWZbUxb1xnHf7av7%2FX19cU2xoDBBEoJBAxJ6FJIaLYubZdKrdalW6Zu3bRN2qYp1bRqm9QvlaapUrcvU7Sqa%2BmHfli%2BbFNftGpV05ZV2Zq2NLRpIC%2BU0qQ0GBJejI2N8TV%2BvftAcCDYYCDt%2FpLl63v%2Bz3N%2Bvr7nnOf4ous6%2F8%2FX03999fUX3jjVtdE4g67rfNn64zMvPjUaiv1gLk3px1fnDNvKFNpqy6PbytSPf3H463uLyfGlgf%2Fh6X8cmZpP%2Fja4kL1lJKgZtUQ6r29XrUuvr3SGat32137yrTt%2BXCjfFwr%2BxJ%2F%2F3hVNZp6b0tLNoiQKjdVlzC%2Bk%2BNeHnxWMUSSRzmYvCd1E5y3Onh%2Fdv%2FfefD7hiwB%2B%2FOjfTk1FEy3TC1nVPxPLnT89MkOZKnGnz0tTlYP3hyc5758BYL%2BvBrMkMzaboHdUA%2BBr28u0Qn3cVPDf%2F%2BWFjw2i2Pza0ExBz0w0wduD47w9OM7dO7fx0x07GRif5%2FRVDUgV3ddNBZ%2BNLohvj0zSXGVHEU3EM1kGx8IrPN6yEhq8buIZA2cmNWSbzuBE%2FgtbLn56aHrg9XHNuP3lup3ff%2FQLA1%2FS0NUIAFZJwFdtx11iQVYUIkkTo6E4p0Zj62RYlJkw5cnnqzMov4p89NovY6Y9g0mTp7uu7aHumwZ%2B8mTfWyVW6Zbl57REmsErEbgS4cDues6MRTeV20QMe%2Bak0Z452RYQHnx2bCBw1LgV2BMnep%2F64IOB8cuXRzMdHa13i6J53Xy%2FfqAdj1PZUD9zxtsJiYeZk76J23wBRQjpm7riZ84M%2BG021dPZ2SqYTKai4372DR8P7d%2BOx2nlsWPvren1OiTCWR8R6RA24wgmzq5o3xS4u8xRk0plmJoKUF7uRhCKg2%2BscjC%2FkOL5fw%2FmbZfNRnZUKFSqMiFtAVlMYzfm924KXBBMqOrizx2LRYlEYsiyBYPBsGbcY8few%2BNUmJi9Pjh1XcfnUai2W0HX6RmeARbHwgM7SwszbBS6p%2BedI22tdbnPkihycczPu%2BdHUa0K9%2B2u48J4gOULz3ItQXsdEo1uG9vLZHo%2FCzE4UdxMsyHw48f%2F26Wq1qMVFa6v7NvXJsxHo5y%2FOM775%2FwMXQkzHIixvPbwOKwc7txOYE5jcHyGmWgCAJci0FCmUO2wcNo%2Fx4mLQYyCkXgquyHodcFPnux7y25XO7q62lSLxZI7f%2ByNft4dnmY8lH%2FhmAhrvNR3EYB9jZUcbHMgWQSyCPSNRmA0smHQ5cpmMRcEHxg4F6isdJapqpXl0AD9o7MYjQbaaxyIFjN9FwOr4vftqEK2Kvhnk%2FQPhXnkQC19%2FYVLgWKk6VWEUm1ohlpTQfD5aDxSV%2BspAwgEAiSTGUpKbKiqDQD%2FTAz%2FNW9zlR2XImIyC8iKjUAsQ%2F%2BExtIg24qSupNQ2sdCtgKX%2BTRe8U1ChjsXirrHVdviDBKZizEycmVV%2B9ISv6feRd%2FE1mFls5F2rw2rKBHJNFBpfneVpyjwkc%2BvYjaL1NSUU1HhhuPntwyXTz6PQku5mX1Vn9NV1s2Y4ee49Q%2FzeguCm0wm16h%2FGrfbSUtLQ1Edb2QVXZJihgdaHbS45znkPVp0XEFwgwGbvUQmHo8TjZpy9%2FZaMmAC1t9RuRSB1kob7Z4F2j3DNFleLBp4SQXBU%2BkMDocKQDab5eqVSTCA02nfcCcARgy0e1Vu9%2Bp0lJ%2Bh1f4fAIKGA8V81%2BLBjQZDrs1oNFJaWgJAIpmgvdaNzSIxdCVEoU3vknweheYKGyWyge4Df8rjWLtMuFEZZOIpm2UF%2BIkTvU%2FZbNbvlJc7PZJkzhsoiSL9owGGr0a4b3ctug7js1HO%2B0M5j9ch0VJZgioZefnsFIMTMZ6sKVx3FCNNryKcbiNpbqKk9s6k0NPzzhFFkY%2B43c7m5WXqTCC0Tio4PjCaOz7ceStGo4H6aoXT%2Fjl6Plm9KG1UWUxMp%2FaimXbiqruLKrsbgFAokhXq6yueFUWR0tLSTc0KS3qp7zP21Lu4MDu%2FJdgMMuF0E9FMA0mxlNrbnszrExSrjCxbcuWpqlpxOp1b6nwzCmebmU9vQ9ehRnoTlzDAmPS7gv7cPS6JIuVuEVhc4sGox%2BMLBlm2FIpdnaxwBZFXml5FNO0mmjlEnfQKDnGo6Ni8e0TVppBOpwxgYGIyTCgUI51ee%2FZYI90KJXUn06lOLicOkdHNqOZp6qRXrhtK7gCxct08a14iWZaQZQmAcEQjHo9hU0Ss0saurEsRSGUk%2FIn7kE0Bys19ubYg9deNyi6ofQJSU%2FDJw5sEv2Eb5rBbcVxbex7ev4MmT4DB8ZkV0%2BCN8nkUbi1T2dPgptkdoyZ%2BPF9H1w9L9i%2B%2BTx0rmFPTNMLhaGJTe87WhnJub9sGQM%2Bpiwz5Z%2Fno8iRwbQ73lNBSZed7996Wixm7dHr9xBPPwOybsHBpxelkMkkoFI1Ho9q5RCL1m9bW%2Bl4hnc5shj2ng3u3c3AvBGZjnLs0SVd7Mx735soCIAed1J0kkxn90qXxC4lEstvnq%2B%2BurHTlbEIwtPCIpmUft1oFj6JIRqNxc%2F8RuZ0K7Q3urUEDwfTubDTjndCy3pdbOu56tJBP2L17RzfQDXD27Kf%2FtMrmr9psYikbLSI2KV3XiWbq9HC6MaRlqweaOn54j2v9sJWDc9euxgcB%2BvuHu8xmy6szwXmrqooWSRSLgjALxfkgtyVLRHRfOpVqOdi699u9RQffCL6k9vamXsAFi19CkkzPWa3mZpsiCoJQeDyvV51eW86zs%2BnGwUTW1e3rPNy9%2FoydXxt6lDIw8MkR2SI%2BLpiz1U6Hyo3jYS66wLZtNavigsEQwenxVDo63N3S8d2C9%2B1GtOlnQOfPfXrMYjHfb7OJpbIsGmAluKZpBIPRoKbFB5qa6u65GbDLteWHV4vjwXjUYhFaTEZdla32FfPtTeJcpf8Bf0u4HEa2VhUAAAAASUVORK5CYII%3D" title="Deployment status for &#x27;TestPyPI (PyPackIT-Test1)&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/TestPyPI (PyPackIT-Test1-TestSuite)"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/TestPyPI (PyPackIT-Test1-TestSuite)?label=CD%20TestPyPI%20%28PyPackIT-Test1-TestSuite%29&amp;style=flat-square&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAAC4AAAApCAYAAABKvBuPAAAACXBIWXMAAAewAAAHsAHUgoNiAAAIn0lEQVRYhcWZbUxb1xnHf7av7%2FX19cU2xoDBBEoJBAxJ6FJIaLYubZdKrdalW6Zu3bRN2qYp1bRqm9QvlaapUrcvU7Sqa%2BmHfli%2BbFNftGpV05ZV2Zq2NLRpIC%2BU0qQ0GBJejI2N8TV%2BvftAcCDYYCDt%2FpLl63v%2Bz3N%2Bvr7nnOf4ous6%2F8%2FX03999fUX3jjVtdE4g67rfNn64zMvPjUaiv1gLk3px1fnDNvKFNpqy6PbytSPf3H463uLyfGlgf%2Fh6X8cmZpP%2Fja4kL1lJKgZtUQ6r29XrUuvr3SGat32137yrTt%2BXCjfFwr%2BxJ%2F%2F3hVNZp6b0tLNoiQKjdVlzC%2Bk%2BNeHnxWMUSSRzmYvCd1E5y3Onh%2Fdv%2FfefD7hiwB%2B%2FOjfTk1FEy3TC1nVPxPLnT89MkOZKnGnz0tTlYP3hyc5758BYL%2BvBrMkMzaboHdUA%2BBr28u0Qn3cVPDf%2F%2BWFjw2i2Pza0ExBz0w0wduD47w9OM7dO7fx0x07GRif5%2FRVDUgV3ddNBZ%2BNLohvj0zSXGVHEU3EM1kGx8IrPN6yEhq8buIZA2cmNWSbzuBE%2FgtbLn56aHrg9XHNuP3lup3ff%2FQLA1%2FS0NUIAFZJwFdtx11iQVYUIkkTo6E4p0Zj62RYlJkw5cnnqzMov4p89NovY6Y9g0mTp7uu7aHumwZ%2B8mTfWyVW6Zbl57REmsErEbgS4cDues6MRTeV20QMe%2Bak0Z452RYQHnx2bCBw1LgV2BMnep%2F64IOB8cuXRzMdHa13i6J53Xy%2FfqAdj1PZUD9zxtsJiYeZk76J23wBRQjpm7riZ84M%2BG021dPZ2SqYTKai4372DR8P7d%2BOx2nlsWPvren1OiTCWR8R6RA24wgmzq5o3xS4u8xRk0plmJoKUF7uRhCKg2%2BscjC%2FkOL5fw%2FmbZfNRnZUKFSqMiFtAVlMYzfm924KXBBMqOrizx2LRYlEYsiyBYPBsGbcY8few%2BNUmJi9Pjh1XcfnUai2W0HX6RmeARbHwgM7SwszbBS6p%2BedI22tdbnPkihycczPu%2BdHUa0K9%2B2u48J4gOULz3ItQXsdEo1uG9vLZHo%2FCzE4UdxMsyHw48f%2F26Wq1qMVFa6v7NvXJsxHo5y%2FOM775%2FwMXQkzHIixvPbwOKwc7txOYE5jcHyGmWgCAJci0FCmUO2wcNo%2Fx4mLQYyCkXgquyHodcFPnux7y25XO7q62lSLxZI7f%2ByNft4dnmY8lH%2FhmAhrvNR3EYB9jZUcbHMgWQSyCPSNRmA0smHQ5cpmMRcEHxg4F6isdJapqpXl0AD9o7MYjQbaaxyIFjN9FwOr4vftqEK2Kvhnk%2FQPhXnkQC19%2FYVLgWKk6VWEUm1ohlpTQfD5aDxSV%2BspAwgEAiSTGUpKbKiqDQD%2FTAz%2FNW9zlR2XImIyC8iKjUAsQ%2F%2BExtIg24qSupNQ2sdCtgKX%2BTRe8U1ChjsXirrHVdviDBKZizEycmVV%2B9ISv6feRd%2FE1mFls5F2rw2rKBHJNFBpfneVpyjwkc%2BvYjaL1NSUU1HhhuPntwyXTz6PQku5mX1Vn9NV1s2Y4ee49Q%2FzeguCm0wm16h%2FGrfbSUtLQ1Edb2QVXZJihgdaHbS45znkPVp0XEFwgwGbvUQmHo8TjZpy9%2FZaMmAC1t9RuRSB1kob7Z4F2j3DNFleLBp4SQXBU%2BkMDocKQDab5eqVSTCA02nfcCcARgy0e1Vu9%2Bp0lJ%2Bh1f4fAIKGA8V81%2BLBjQZDrs1oNFJaWgJAIpmgvdaNzSIxdCVEoU3vknweheYKGyWyge4Df8rjWLtMuFEZZOIpm2UF%2BIkTvU%2FZbNbvlJc7PZJkzhsoiSL9owGGr0a4b3ctug7js1HO%2B0M5j9ch0VJZgioZefnsFIMTMZ6sKVx3FCNNryKcbiNpbqKk9s6k0NPzzhFFkY%2B43c7m5WXqTCC0Tio4PjCaOz7ceStGo4H6aoXT%2Fjl6Plm9KG1UWUxMp%2FaimXbiqruLKrsbgFAokhXq6yueFUWR0tLSTc0KS3qp7zP21Lu4MDu%2FJdgMMuF0E9FMA0mxlNrbnszrExSrjCxbcuWpqlpxOp1b6nwzCmebmU9vQ9ehRnoTlzDAmPS7gv7cPS6JIuVuEVhc4sGox%2BMLBlm2FIpdnaxwBZFXml5FNO0mmjlEnfQKDnGo6Ni8e0TVppBOpwxgYGIyTCgUI51ee%2FZYI90KJXUn06lOLicOkdHNqOZp6qRXrhtK7gCxct08a14iWZaQZQmAcEQjHo9hU0Ss0saurEsRSGUk%2FIn7kE0Bys19ubYg9deNyi6ofQJSU%2FDJw5sEv2Eb5rBbcVxbex7ev4MmT4DB8ZkV0%2BCN8nkUbi1T2dPgptkdoyZ%2BPF9H1w9L9i%2B%2BTx0rmFPTNMLhaGJTe87WhnJub9sGQM%2Bpiwz5Z%2Fno8iRwbQ73lNBSZed7996Wixm7dHr9xBPPwOybsHBpxelkMkkoFI1Ho9q5RCL1m9bW%2Bl4hnc5shj2ng3u3c3AvBGZjnLs0SVd7Mx735soCIAed1J0kkxn90qXxC4lEstvnq%2B%2BurHTlbEIwtPCIpmUft1oFj6JIRqNxc%2F8RuZ0K7Q3urUEDwfTubDTjndCy3pdbOu56tJBP2L17RzfQDXD27Kf%2FtMrmr9psYikbLSI2KV3XiWbq9HC6MaRlqweaOn54j2v9sJWDc9euxgcB%2BvuHu8xmy6szwXmrqooWSRSLgjALxfkgtyVLRHRfOpVqOdi699u9RQffCL6k9vamXsAFi19CkkzPWa3mZpsiCoJQeDyvV51eW86zs%2BnGwUTW1e3rPNy9%2FoydXxt6lDIw8MkR2SI%2BLpiz1U6Hyo3jYS66wLZtNavigsEQwenxVDo63N3S8d2C9%2B1GtOlnQOfPfXrMYjHfb7OJpbIsGmAluKZpBIPRoKbFB5qa6u65GbDLteWHV4vjwXjUYhFaTEZdla32FfPtTeJcpf8Bf0u4HEa2VhUAAAAASUVORK5CYII%3D" title="Deployment status for &#x27;TestPyPI (PyPackIT-Test1-TestSuite)&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/Zenodo"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/Zenodo?label=CD%20Zenodo&amp;style=flat-square&amp;logo=zenodo" title="Deployment status for &#x27;Zenodo&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/Zenodo Sandbox"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/Zenodo Sandbox?label=CD%20Zenodo%20Sandbox&amp;style=flat-square&amp;logo=zenodo" title="Deployment status for &#x27;Zenodo Sandbox&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/GitHub Release"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/GitHub Release?label=CD%20GitHub%20Release&amp;style=flat-square&amp;logo=github" title="Deployment status for &#x27;GitHub Release&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Deployment Status" href="https://github.com/AAriam/PyPackIT-Test1/deployments/GitHub Pages"><img alt="Deployment Status" height="23px" src="https://img.shields.io/github/deployments/AAriam/PyPackIT-Test1/GitHub Pages?label=CD%20GitHub%20Pages&amp;style=flat-square&amp;logo=github" title="Deployment status for &#x27;GitHub Pages&#x27; environment." /></a>&nbsp;&nbsp;<a alt="Website Build Status" href="https://readthedocs.org/projects/PyPackIT-Test1/builds"><img alt="Website Build Status" height="23px" src="https://img.shields.io/readthedocs/PyPackIT-Test1?label=CD%20ReadTheDocs&amp;style=flat-square&amp;logo=readthedocs" title="Website build status. Click to see more details on the ReadTheDocs platform." /></a>

</td></tr></tbody></table></figure>

<hr />

<a alt="PyPackIT Test1: Copyright © 2024 Armin Ariamajd" href="https://github.com/AAriam"><img align="left" alt="PyPackIT Test1: Copyright © 2024 Armin Ariamajd" src="https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fraw.githubusercontent.com%2FAAriam%2FPyPackIT-Test1%2Fmain%2F.github%2F.repodynamics%2Fmetadata.json&amp;query=%24.copyright&amp;label=PyPackIT%20Test1&amp;style=for-the-badge&amp;color=%230F3460&amp;logo=data%3Aimage%2Fsvg%2Bxml%3Bbase64%2CPD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPHN2ZyBpZD0iTGF5ZXJfMiIgZGF0YS1uYW1lPSJMYXllciAyIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA4OSA4OSI%2BCiAgPGRlZnM%2BCiAgICA8c3R5bGU%2BCiAgICAgIC5jbHMtMSB7CiAgICAgICAgZmlsbDogIzAwOTI0NTsKICAgICAgfQoKICAgICAgLmNscy0xLCAuY2xzLTIgewogICAgICAgIHN0cm9rZTogI2ZmZjsKICAgICAgICBzdHJva2UtbWl0ZXJsaW1pdDogMTA7CiAgICAgIH0KCiAgICAgIC5jbHMtMiB7CiAgICAgICAgZmlsbDogI2MxMjcyZDsKICAgICAgfQogICAgPC9zdHlsZT4KICA8L2RlZnM% %2BCjwvc3ZnPgo%3D" title="PyPackIT Test1: Copyright © 2024 Armin Ariamajd" /></a>&nbsp;<a alt="SPDX-License-Identifier: MIT" href="https://AAriam.github.io/PyPackIT-Test1/about/license"><img align="right" alt="SPDX-License-Identifier: MIT" src="https://img.shields.io/static/v1?message=MIT&amp;label=SPDX%20License%20Identifier&amp;style=for-the-badge&amp;color=%234398CC&amp;logoColor=%234398CC&amp;logo=spdx" title="SPDX-License-Identifier: MIT" /></a>

<a alt="Powered by PyPackIT" href="https://pypackit.repodynamics.com"><img align="right" alt="Powered by PyPackIT" src="https://img.shields.io/static/v1?message=PyPackIT&amp;logo=data%3Aimage%2Fpng%3Bbase64%2CiVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAACXBIWXMAAAsPAAALDwGS%2BQOlAAADxklEQVRYhb1XbWxTZRR%2B3vvR3rt%2BOsJ2M5CWrKIxZJsm%2FgITk0XBjYQ4IJshAcJHjIq4HyyKgjJBPiLqwg8Tk6L80qATgwkLGpUE94OYSBgSIZnTFoK93VxhpV1v73s%2FTGu6rOu69nZlz6%2Fzvue85zw55z73vZeYpgkraDr85IX7NLEGFHDrrtDQ8d%2BWW0owA4yV4LVH2juHyV9rQuYthPQwrqnX%2FU%2F3PHNswQhEmbFNCpS8vZgWW71gBFJECRQkIMyK%2BRDgZtvsOtV2Om5OBmomPZv795wLz%2FRLpB5gTMiIImEkF8%2BHQEEHXvr0xdXjzsjWO67QqiSX6J3uSyPdLEDAI2jc9Tj72AGBCPOpnUVBB1Re6UrZkvDEa5HkkgXzlcw6XOr9OZixl%2FesOATDmopKEtBZKi2JBX7VVTIa4aLr5pW9DBSMQGPVAAFu1FDXTw%2B6eAazqsCpeK%2BWOti6%2FzmfYiqlwkpiVhWUAzuxvyDrUfixbM7oXR%2Bs7055wttEkcDBi1yN%2FlD7kc3np5RVMYHZsHbP853%2Fmndes4mGkxe1gCDCwTvTgGMMuosBXATC3eaMsrbljlt6ETFgksV8ra8%2F6%2Ft94npwOHVzVZgON8tmyDHO3kKCG82L073y1oNft%2FsqIsCD%2F7OYTzXUlyNKxFkqh%2B4eAwjeya2rNoIJbaKl3FhTTKx%2Fv7%2BjlVXcgqUOzAXVoFK5sWTS2ff2xrN%2BtvbuxgICJjGn2iiL%2F2DDhx3d5SQ1YJRsfwbcmC96cNP5wxm7p%2B3cYHYE%2Bz7f0UkpWpL2%2BEqGZRqDr37Rt%2BVkV1mFc6AGbcyYdTYp4bM1fGMngKAxUKm8wcRolhyj2cHG607nEXo3%2BIqZXirjnn0c96kKQZa%2Bt1J4Jlyse%2BTH45enZLbjRFuQ3Fv2BhB7SkiJV492%2FvBmHoHenZ%2BQfZ%2Ft7PZwHkmkWEx14z0rBUNqGG171xXt1qm9A4MABov5syM4uj3YZ6VoNVE1FVSKigkY0CO5D5IbqZsfy%2Blo1nawjpIX2XRUTODCoYEzEluftUNKGIpR2c1Y9RGwhEssGAE7sQ1NXwusADfr%2BWXBCHgZb568logN0e9ODJypKoEYH5u6ZDRoEg9%2BJLe%2BfGxwd5OwMuQXfPCLPjQIDfutFM%2Bg5G14W7jd0XTyiRZCWc8I%2B3f9ozQgT%2FcPfXTlwfwbUkb9tja9CHFuwjVsH2m%2BZvvDn9m3gZeLnakqgS93nw07NFf%2BQ2YK8Jre%2FmoSmHMETs351lL94a%2BSuupQqY46bdHFSwf%2B%2FympCgD8BxQORGJUan2aAAAAAElFTkSuQmCC&amp;color=rgb%280%2C%20100%2C%200%29&amp;label=Powered%20By&amp;style=for-the-badge" title="Automated project management and DevOps by PyPackIT." /></a>
